from testcase.apache.beam_class import AverageFn, AverageFn2
from huhk.unit_apache_beam import ApacheFun


class TestPolymerization:
    # 通过键聚合所有输入元素，并允许下游处理使用与键关联的所有值
    def test_polymerization_001(self):
        ApacheFun(data_type=data_type).co_group_by_key(icons=data_list_tuple3, durations=data_list_tuple4).print()

    def test_polymerization_002(self):
        ApacheFun(data_type=data_type).co_group_by_key(data_list_tuple3, data_list_tuple4, data_list_tuple4).print()

    # 组合集合中的所有元素
    def test_polymerization_003(self):
        def get_common_items(sets):
            return set.intersection(*(sets or [set()]))
        ApacheFun(data_list_set, data_type=data_type).combine_globally(get_common_items).print()

    def test_polymerization_004(self):
        ApacheFun(data_list_set, data_type=data_type).combine_globally(lambda sets: set.intersection(*(sets or [set()]))).print()

    def test_polymerization_005(self):
        ApacheFun(data_list_set, data_type=data_type).combine_globally(
            lambda sets, exclude: set.intersection(*(sets or [set()])) - exclude, exclude={'🥕'}).print()

    def test_polymerization_006(self):
        ApacheFun(data_list2, data_type=data_type).combine_percentages_fn(type=3).print()

    # 组合集合中每个键的所有元素
    def test_combine_per_key_007(self):
        ApacheFun(data_list_tuple5, data_type=data_type).combine_per_key(sum).print()

    def test_combine_per_key_008(self):
        def saturated_sum(values):
            max_value = 8
            return min(sum(values), max_value)
        ApacheFun(data_list_tuple5, data_type=data_type).combine_per_key(saturated_sum).print()

    def test_combine_per_key_009(self):
        ApacheFun(data_list_tuple5, data_type=data_type).combine_per_key(lambda values: min(sum(values), 8)).print()

    def test_combine_per_key_010(self):
        ApacheFun(data_list_tuple5, data_type=data_type).combine_per_key(
            lambda values, max_value: min(sum(values), max_value), max_value=8).print()

    def test_combine_per_key_011(self):
        ApacheFun(data_list_tuple5, data_type=data_type).combine_per_key(AverageFn()).print()

    # 在键控元素集合中组合可迭代的值
    def test_combine_values_012(self):
        ApacheFun(data_list_tuple_list, data_type=data_type).combine_values(sum).print()

    def test_combine_values_013(self):
        def saturated_sum(values):
            max_value = 8
            return min(sum(values), max_value)
        ApacheFun(data_list_tuple_list, data_type=data_type).combine_values(saturated_sum).print()

    def test_combine_values_014(self):
        ApacheFun(data_list_tuple_list, data_type=data_type).combine_values(lambda values: min(sum(values), 8)).print()

    def test_combine_values_015(self):
        ApacheFun(data_list_tuple_list, data_type=data_type).combine_values(
            lambda values, max_value: min(sum(values), max_value), max_value=8).print()

    def test_combine_values_016(self):
        ApacheFun(data_list_tuple_list2, data_type=data_type).combine_values(AverageFn2()).print()

    # 计算每个聚合中的元素个数
    def test_count_017(self):
        ApacheFun(data_list2, data_type=data_type).count_globally().print()

    def test_count_018(self):
        ApacheFun(data_list_tuple5, data_type=data_type).count_per_key().print()

    def test_count_019(self):
        ApacheFun(data_list2, data_type=data_type).count_per_element().print()

    # 生成一个包含输入集合的不同元素的集合
    def test_distinct_020(self):
        ApacheFun(data_list2, data_type=data_type).distinct().print()

    def test_group_by_key_021(self):
        ApacheFun(data_list_tuple5, data_type=data_type).group_by_key().print()

    def test_group_by_022(self):
        ApacheFun(data_list2, data_type=data_type).group_by(lambda s: s[0]).print()

    def test_group_by_023(self):
        ApacheFun(data_list, data_type=data_type).group_by(letter=lambda s: s[0], is_berry=lambda s: 'bie' in s).print()

    def test_group_by_024(self):
        ApacheFun(data_list_group, data_type=data_type).group_by('recipe').print()

    def test_group_by_025(self):
        ApacheFun(data_list_group, data_type=data_type).group_by("recipe", is_berry=lambda x: 'berry' in x.fruit).print()

    def test_group_by_026(self):
        ApacheFun(data_list_group, data_type=data_type).group_by("recipe")\
            .aggregate_field('quantity', sum, 'total_quantity').print()

    def test_group_by_027(self):
        af = ApacheFun(data_list_group, data_type=data_type)
        af.group_by()
        af.aggregate_field('quantity', sum, 'total_quantity')
        af.aggregate_field(lambda x: x.quantity * x.unit_price, sum, 'price')
        af.print()

    def test_group_into_batches_028(self):
        ApacheFun(data_list_tuple5, data_type=data_type).group_into_batches(2).print()

    def test_latest_globally_029(self):
        af = ApacheFun(data_list_dict3)
        af.latest_globally("season")
        af.print()

    def test_latest_per_key_030(self):
        af = ApacheFun(data_list_tuple_dict)
        af.latest_per_key("harvest", "item")
        af.print()

    def test_max_031(self):
        ApacheFun(data_list3, data_type=data_type).max().print()

    def test_max_032(self):
        ApacheFun(data_list_tuple5, data_type=data_type).max().print()

    def test_min_033(self):
        ApacheFun(data_list3, data_type=data_type).min().print()

    def test_min_034(self):
        ApacheFun(data_list_tuple5, data_type=data_type).min().print()

    def test_mean_035(self):
        """入：[3, 4, 1, 2]
           出：2.5"""
        ApacheFun(data_list3, data_type=data_type).mean().print()

    def test_mean_036(self):
        """入：[('🥕', 3), ('🥕', 2), ('🍆', 1), ('🍅', 4), ('🍅', 5), ('🍅', 1)]
           出:('🥕', 2.5) ('🍆', 1.0) ('🍅', 3.3333333333333335)"""
        ApacheFun(data_list_tuple5, data_type=data_type).mean().print()

    def test_sum_037(self):
        ApacheFun(data_list3, data_type=data_type).sum().print()

    def test_sum_038(self):
        ApacheFun(data_list_tuple5, data_type=data_type).sum().print()

    def test_sample_039(self):
        ApacheFun(data_list3, data_type=data_type).sample(2).print()

    def test_sample_040(self):
        ApacheFun(data_list_tuple5, data_type=data_type).sample(2).print()

    def test_top_041(self):
        ApacheFun(data_list3, data_type=data_type).top_largest(2).print()

    def test_top_042(self):
        ApacheFun(data_list_tuple5, data_type=data_type).top_largest(2).print()

    def test_top_043(self):
        ApacheFun(data_list3, data_type=data_type).top_smallest(2).print()

    def test_top_044(self):
        ApacheFun(data_list_tuple5, data_type=data_type).top_smallest(2).print()

    def test_top_045(self):
        ApacheFun(data_list3, data_type=data_type).top_of(2).print()

    def test_top_046(self):
        ApacheFun(data_list_tuple5, data_type=data_type).top_of(1).print()


import requests

from huhk.unit_fun import FunBase
from huhk import admin_host


class AppTFun(FunBase):
    def __init__(self):
        super().__init__()
        self.res = None

    @staticmethod
    def run_mysql(sql_str, db_id=1):
        # 根据后台数据库配置id查询
        out = requests.post(admin_host + "/sql/running_sql/", json={"id": db_id, "sql_str": sql_str}).json()
        if out.get("code") == "0000":
            return out.get("data")
        else:
            assert False, sql_str + str(out.get("msg"))


if __name__ == '__main__':
    f = AppTFun()
    out = f.faker().name()
    print(out)




import allure

from service.app_t import http_requester
from huhk.unit_request import get_url


@allure.step(title="调接口：/open/haohan/relation/update")
def open_haohan_relation_update(userId=None, headers=None, **kwargs):
    """
    浩瀚模块-关联关系-Y
    up_time=1675665418

    params: userId :  : 用户ID（数据类型：String）
    params: headers : 请求头
    ====================返回======================
    """
    _method = "GET"
    _url = "/open/haohan/relation/update"

    _headers = {
    }
    _headers.update({"headers": headers})

    _data = {
        "userId": userId,  # 用户ID（数据类型：String）
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/open/haohan/relation/update")
def open_haohan_relation_update(userId=None, headers=None, **kwargs):
    """
    浩瀚模块-关联关系-Y
    up_time=1675665418

    params: userId :  : 用户ID（数据类型：String）
    params: headers : 请求头
    ====================返回======================
    """
    _method = "GET"
    _url = "/open/haohan/relation/update"

    _headers = {
    }
    _headers.update({"headers": headers})

    _data = {
        "userId": userId,  # 用户ID（数据类型：String）
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/open/haohan/relation/update")
def open_haohan_relation_update(userId=None, headers=None, **kwargs):
    """
    浩瀚模块-关联关系-Y
    up_time=1675665418

    params: userId :  : 用户ID（数据类型：String）
    params: headers : 请求头
    ====================返回======================
    """
    _method = "GET"
    _url = "/open/haohan/relation/update"

    _headers = {
    }
    _headers.update({"headers": headers})

    _data = {
        "userId": userId,  # 用户ID（数据类型：String）
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/open/haohan/relation/update")
def open_haohan_relation_update(userId=None, headers=None, **kwargs):
    """
    浩瀚模块-关联关系-Y
    up_time=1675665418

    params: userId :  : 用户ID（数据类型：String）
    params: headers : 请求头
    ====================返回======================
    """
    _method = "GET"
    _url = "/open/haohan/relation/update"

    _headers = {
    }
    _headers.update({"headers": headers})

    _data = {
        "userId": userId,  # 用户ID（数据类型：String）
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/open/haohan/relation/update")
def open_haohan_relation_update(userId=None, headers=None, **kwargs):
    """
    浩瀚模块-关联关系-Y
    up_time=1675665418

    params: userId :  : 用户ID（数据类型：String）
    params: headers : 请求头
    ====================返回======================
    """
    _method = "GET"
    _url = "/open/haohan/relation/update"

    _headers = {
    }
    _headers.update({"headers": headers})

    _data = {
        "userId": userId,  # 用户ID（数据类型：String）
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/open/haohan/relation/update")
def open_haohan_relation_update(userId=None, headers=None, **kwargs):
    """
    浩瀚模块-关联关系-Y
    up_time=1675665418

    params: userId :  : 用户ID（数据类型：String）
    params: headers : 请求头
    ====================返回======================
    """
    _method = "GET"
    _url = "/open/haohan/relation/update"

    _headers = {
    }
    _headers.update({"headers": headers})

    _data = {
        "userId": userId,  # 用户ID（数据类型：String）
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/open/haohan/relation/update")
def open_haohan_relation_update(userId=None, headers=None, **kwargs):
    """
    浩瀚模块-关联关系-Y
    up_time=1675665418

    params: userId :  : 用户ID（数据类型：String）
    params: headers : 请求头
    ====================返回======================
    """
    _method = "GET"
    _url = "/open/haohan/relation/update"

    _headers = {
    }
    _headers.update({"headers": headers})

    _data = {
        "userId": userId,  # 用户ID（数据类型：String）
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/open/haohan/relation/update")
def open_haohan_relation_update(userId=None, headers=None, **kwargs):
    """
    浩瀚模块-关联关系-Y
    up_time=1675665418

    params: userId :  : 用户ID（数据类型：String）
    params: headers : 请求头
    ====================返回======================
    """
    _method = "GET"
    _url = "/open/haohan/relation/update"

    _headers = {
    }
    _headers.update({"headers": headers})

    _data = {
        "userId": userId,  # 用户ID（数据类型：String）
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/open/haohan/relation/update")
def open_haohan_relation_update(userId=None, headers=None, **kwargs):
    """
    浩瀚模块-关联关系-Y
    up_time=1675665418

    params: userId :  : 用户ID（数据类型：String）
    params: headers : 请求头
    ====================返回======================
    """
    _method = "GET"
    _url = "/open/haohan/relation/update"

    _headers = {
    }
    _headers.update({"headers": headers})

    _data = {
        "userId": userId,  # 用户ID（数据类型：String）
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/open/haohan/relation/update")
def open_haohan_relation_update(userId=None, headers=None, **kwargs):
    """
    浩瀚模块-关联关系-Y
    up_time=1675665418

    params: userId :  : 用户ID（数据类型：String）
    params: headers : 请求头
    ====================返回======================
    """
    _method = "GET"
    _url = "/open/haohan/relation/update"

    _headers = {
    }
    _headers.update({"headers": headers})

    _data = {
        "userId": userId,  # 用户ID（数据类型：String）
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/open/haohan/relation/update")
def open_haohan_relation_update(userId=None, headers=None, **kwargs):
    """
    浩瀚模块-关联关系-Y
    up_time=1675665418

    params: userId :  : 用户ID（数据类型：String）
    params: headers : 请求头
    ====================返回======================
    """
    _method = "GET"
    _url = "/open/haohan/relation/update"

    _headers = {
    }
    _headers.update({"headers": headers})

    _data = {
        "userId": userId,  # 用户ID（数据类型：String）
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/open/haohan/relation/update")
def open_haohan_relation_update(userId=None, headers=None, **kwargs):
    """
    浩瀚模块-关联关系-Y
    up_time=1675665418

    params: userId :  : 用户ID（数据类型：String）
    params: headers : 请求头
    ====================返回======================
    """
    _method = "GET"
    _url = "/open/haohan/relation/update"

    _headers = {
    }
    _headers.update({"headers": headers})

    _data = {
        "userId": userId,  # 用户ID（数据类型：String）
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/open/haohan/relation/update")
def open_haohan_relation_update(userId=None, headers=None, **kwargs):
    """
    浩瀚模块-关联关系-Y
    up_time=1675665418

    params: userId :  : 用户ID（数据类型：String）
    params: headers : 请求头
    ====================返回======================
    """
    _method = "GET"
    _url = "/open/haohan/relation/update"

    _headers = {
    }
    _headers.update({"headers": headers})

    _data = {
        "userId": userId,  # 用户ID（数据类型：String）
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/open/haohan/relation/update")
def open_haohan_relation_update(userId=None, headers=None, **kwargs):
    """
    浩瀚模块-关联关系-Y
    up_time=1675665418

    params: userId :  : 用户ID（数据类型：String）
    params: headers : 请求头
    ====================返回======================
    """
    _method = "GET"
    _url = "/open/haohan/relation/update"

    _headers = {
    }
    _headers.update({"headers": headers})

    _data = {
        "userId": userId,  # 用户ID（数据类型：String）
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/open/haohan/relation/update")
def open_haohan_relation_update(userId=None, headers=None, **kwargs):
    """
    浩瀚模块-关联关系-Y
    up_time=1675665418

    params: userId :  : 用户ID（数据类型：String）
    params: headers : 请求头
    ====================返回======================
    """
    _method = "GET"
    _url = "/open/haohan/relation/update"

    _headers = {
    }
    _headers.update({"headers": headers})

    _data = {
        "userId": userId,  # 用户ID（数据类型：String）
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/open/haohan/relation/update")
def open_haohan_relation_update(userId=None, headers=None, **kwargs):
    """
    浩瀚模块-关联关系-Y
    up_time=1675665418

    params: userId :  : 用户ID（数据类型：String）
    params: headers : 请求头
    ====================返回======================
    """
    _method = "GET"
    _url = "/open/haohan/relation/update"

    _headers = {
    }
    _headers.update({"headers": headers})

    _data = {
        "userId": userId,  # 用户ID（数据类型：String）
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/open/haohan/relation/update")
def open_haohan_relation_update(userId=None, headers=None, **kwargs):
    """
    浩瀚模块-关联关系-Y
    up_time=1675665418

    params: userId :  : 用户ID（数据类型：String）
    params: headers : 请求头
    ====================返回======================
    """
    _method = "GET"
    _url = "/open/haohan/relation/update"

    _headers = {
    }
    _headers.update({"headers": headers})

    _data = {
        "userId": userId,  # 用户ID（数据类型：String）
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/open/haohan/relation/update")
def open_haohan_relation_update(userId=None, headers=None, **kwargs):
    """
    浩瀚模块-关联关系-Y
    up_time=1675665418

    params: userId :  : 用户ID（数据类型：String）
    params: headers : 请求头
    ====================返回======================
    """
    _method = "GET"
    _url = "/open/haohan/relation/update"

    _headers = {
    }
    _headers.update({"headers": headers})

    _data = {
        "userId": userId,  # 用户ID（数据类型：String）
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/open/haohan/relation/update")
def open_haohan_relation_update(userId=None, headers=None, **kwargs):
    """
    浩瀚模块-关联关系-Y
    up_time=1675665418

    params: userId :  : 用户ID（数据类型：String）
    params: headers : 请求头
    ====================返回======================
    """
    _method = "GET"
    _url = "/open/haohan/relation/update"

    _headers = {
    }
    _headers.update({"headers": headers})

    _data = {
        "userId": userId,  # 用户ID（数据类型：String）
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/open/haohan/relation/update")
def open_haohan_relation_update(userId=None, headers=None, **kwargs):
    """
    浩瀚模块-关联关系-Y
    up_time=1675665418

    params: userId :  : 用户ID（数据类型：String）
    params: headers : 请求头
    ====================返回======================
    """
    _method = "GET"
    _url = "/open/haohan/relation/update"

    _headers = {
    }
    _headers.update({"headers": headers})

    _data = {
        "userId": userId,  # 用户ID（数据类型：String）
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/open/haohan/relation/update")
def open_haohan_relation_update(userId=None, headers=None, **kwargs):
    """
    浩瀚模块-关联关系-Y
    up_time=1675665418

    params: userId :  : 用户ID（数据类型：String）
    params: headers : 请求头
    ====================返回======================
    """
    _method = "GET"
    _url = "/open/haohan/relation/update"

    _headers = {
    }
    _headers.update({"headers": headers})

    _data = {
        "userId": userId,  # 用户ID（数据类型：String）
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/open/haohan/relation/update")
def open_haohan_relation_update(userId=None, headers=None, **kwargs):
    """
    浩瀚模块-关联关系-Y
    up_time=1675665418

    params: userId :  : 用户ID（数据类型：String）
    params: headers : 请求头
    ====================返回======================
    """
    _method = "GET"
    _url = "/open/haohan/relation/update"

    _headers = {
    }
    _headers.update({"headers": headers})

    _data = {
        "userId": userId,  # 用户ID（数据类型：String）
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/open/haohan/relation/update")
def open_haohan_relation_update(userId=None, headers=None, **kwargs):
    """
    浩瀚模块-关联关系-Y
    up_time=1675665418

    params: userId :  : 用户ID（数据类型：String）
    params: headers : 请求头
    ====================返回======================
    """
    _method = "GET"
    _url = "/open/haohan/relation/update"

    _headers = {
    }
    _headers.update({"headers": headers})

    _data = {
        "userId": userId,  # 用户ID（数据类型：String）
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/open/haohan/relation/update")
def open_haohan_relation_update(userId=None, headers=None, **kwargs):
    """
    浩瀚模块-关联关系-Y
    up_time=1675665418

    params: userId :  : 用户ID（数据类型：String）
    params: headers : 请求头
    ====================返回======================
    """
    _method = "GET"
    _url = "/open/haohan/relation/update"

    _headers = {
    }
    _headers.update({"headers": headers})

    _data = {
        "userId": userId,  # 用户ID（数据类型：String）
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/open/haohan/relation/update")
def open_haohan_relation_update(userId=None, headers=None, **kwargs):
    """
    浩瀚模块-关联关系-Y
    up_time=1675665418

    params: userId :  : 用户ID（数据类型：String）
    params: headers : 请求头
    ====================返回======================
    """
    _method = "GET"
    _url = "/open/haohan/relation/update"

    _headers = {
    }
    _headers.update({"headers": headers})

    _data = {
        "userId": userId,  # 用户ID（数据类型：String）
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/open/haohan/relation/update")
def open_haohan_relation_update(userId=None, headers=None, **kwargs):
    """
    浩瀚模块-关联关系-Y
    up_time=1675665418

    params: userId :  : 用户ID（数据类型：String）
    params: headers : 请求头
    ====================返回======================
    """
    _method = "GET"
    _url = "/open/haohan/relation/update"

    _headers = {
    }
    _headers.update({"headers": headers})

    _data = {
        "userId": userId,  # 用户ID（数据类型：String）
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/open/haohan/relation/update")
def open_haohan_relation_update(userId=None, headers=None, **kwargs):
    """
    浩瀚模块-关联关系-Y
    up_time=1675665418

    params: userId :  : 用户ID（数据类型：String）
    params: headers : 请求头
    ====================返回======================
    """
    _method = "GET"
    _url = "/open/haohan/relation/update"

    _headers = {
    }
    _headers.update({"headers": headers})

    _data = {
        "userId": userId,  # 用户ID（数据类型：String）
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/open/haohan/relation/update")
def open_haohan_relation_update(userId=None, headers=None, **kwargs):
    """
    浩瀚模块-关联关系-Y
    up_time=1675665418

    params: userId :  : 用户ID（数据类型：String）
    params: headers : 请求头
    ====================返回======================
    """
    _method = "GET"
    _url = "/open/haohan/relation/update"

    _headers = {
    }
    _headers.update({"headers": headers})

    _data = {
        "userId": userId,  # 用户ID（数据类型：String）
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/open/haohan/relation/update")
def open_haohan_relation_update(userId=None, headers=None, **kwargs):
    """
    浩瀚模块-关联关系-Y
    up_time=1675665418

    params: userId :  : 用户ID（数据类型：String）
    params: headers : 请求头
    ====================返回======================
    """
    _method = "GET"
    _url = "/open/haohan/relation/update"

    _headers = {
    }
    _headers.update({"headers": headers})

    _data = {
        "userId": userId,  # 用户ID（数据类型：String）
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/open/haohan/relation/update")
def open_haohan_relation_update(userId=None, headers=None, **kwargs):
    """
    浩瀚模块-关联关系-Y
    up_time=1675665418

    params: userId :  : 用户ID（数据类型：String）
    params: headers : 请求头
    ====================返回======================
    """
    _method = "GET"
    _url = "/open/haohan/relation/update"

    _headers = {
    }
    _headers.update({"headers": headers})

    _data = {
        "userId": userId,  # 用户ID（数据类型：String）
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/open/haohan/relation/update")
def open_haohan_relation_update(userId=None, headers=None, **kwargs):
    """
    浩瀚模块-关联关系-Y
    up_time=1675665418

    params: userId :  : 用户ID（数据类型：String）
    params: headers : 请求头
    ====================返回======================
    """
    _method = "GET"
    _url = "/open/haohan/relation/update"

    _headers = {
    }
    _headers.update({"headers": headers})

    _data = {
        "userId": userId,  # 用户ID（数据类型：String）
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)





import allure

from service.app_t import http_requester
from huhk.unit_request import get_url


@allure.step(title="调接口：/open/haohan/rights/update")
def open_haohan_rights_update(params=None, headers=None, **kwargs):
    """
    浩瀚模块 - 更改充电桩权益状态-Y
    up_time=1675665629

    params: params : object : 
              data : string : 加密数据
    params: headers : 请求头
    ====================返回======================
    """
    _method = "POST"
    _url = "/open/haohan/rights/update"

    _headers = {
        "Content-Type": "application/json",
    }
    _headers.update({"headers": headers})

    _data = {
        "params": params,
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/open/haohan/rights/update")
def open_haohan_rights_update(params=None, headers=None, **kwargs):
    """
    浩瀚模块 - 更改充电桩权益状态-Y
    up_time=1675665629

    params: params : object : 
              data : string : 加密数据
    params: headers : 请求头
    ====================返回======================
    """
    _method = "POST"
    _url = "/open/haohan/rights/update"

    _headers = {
        "Content-Type": "application/json",
    }
    _headers.update({"headers": headers})

    _data = {
        "params": params,
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/open/haohan/rights/update")
def open_haohan_rights_update(params=None, headers=None, **kwargs):
    """
    浩瀚模块 - 更改充电桩权益状态-Y
    up_time=1675665629

    params: params : object : 
              data : string : 加密数据
    params: headers : 请求头
    ====================返回======================
    """
    _method = "POST"
    _url = "/open/haohan/rights/update"

    _headers = {
        "Content-Type": "application/json",
    }
    _headers.update({"headers": headers})

    _data = {
        "params": params,
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/open/haohan/rights/update")
def open_haohan_rights_update(params=None, headers=None, **kwargs):
    """
    浩瀚模块 - 更改充电桩权益状态-Y
    up_time=1675665629

    params: params : object : 
              data : string : 加密数据
    params: headers : 请求头
    ====================返回======================
    """
    _method = "POST"
    _url = "/open/haohan/rights/update"

    _headers = {
        "Content-Type": "application/json",
    }
    _headers.update({"headers": headers})

    _data = {
        "params": params,
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/open/haohan/rights/update")
def open_haohan_rights_update(params=None, headers=None, **kwargs):
    """
    浩瀚模块 - 更改充电桩权益状态-Y
    up_time=1675665629

    params: params : object : 
              data : string : 加密数据
    params: headers : 请求头
    ====================返回======================
    """
    _method = "POST"
    _url = "/open/haohan/rights/update"

    _headers = {
        "Content-Type": "application/json",
    }
    _headers.update({"headers": headers})

    _data = {
        "params": params,
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/open/haohan/rights/update")
def open_haohan_rights_update(params=None, headers=None, **kwargs):
    """
    浩瀚模块 - 更改充电桩权益状态-Y
    up_time=1675665629

    params: params : object : 
              data : string : 加密数据
    params: headers : 请求头
    ====================返回======================
    """
    _method = "POST"
    _url = "/open/haohan/rights/update"

    _headers = {
        "Content-Type": "application/json",
    }
    _headers.update({"headers": headers})

    _data = {
        "params": params,
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/open/haohan/rights/update")
def open_haohan_rights_update(params=None, headers=None, **kwargs):
    """
    浩瀚模块 - 更改充电桩权益状态-Y
    up_time=1675665629

    params: params : object : 
              data : string : 加密数据
    params: headers : 请求头
    ====================返回======================
    """
    _method = "POST"
    _url = "/open/haohan/rights/update"

    _headers = {
        "Content-Type": "application/json",
    }
    _headers.update({"headers": headers})

    _data = {
        "params": params,
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/open/haohan/rights/update")
def open_haohan_rights_update(params=None, headers=None, **kwargs):
    """
    浩瀚模块 - 更改充电桩权益状态-Y
    up_time=1675665629

    params: params : object : 
              data : string : 加密数据
    params: headers : 请求头
    ====================返回======================
    """
    _method = "POST"
    _url = "/open/haohan/rights/update"

    _headers = {
        "Content-Type": "application/json",
    }
    _headers.update({"headers": headers})

    _data = {
        "params": params,
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/open/haohan/rights/update")
def open_haohan_rights_update(params=None, headers=None, **kwargs):
    """
    浩瀚模块 - 更改充电桩权益状态-Y
    up_time=1675665629

    params: params : object : 
              data : string : 加密数据
    params: headers : 请求头
    ====================返回======================
    """
    _method = "POST"
    _url = "/open/haohan/rights/update"

    _headers = {
        "Content-Type": "application/json",
    }
    _headers.update({"headers": headers})

    _data = {
        "params": params,
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/open/haohan/rights/update")
def open_haohan_rights_update(params=None, headers=None, **kwargs):
    """
    浩瀚模块 - 更改充电桩权益状态-Y
    up_time=1675665629

    params: params : object : 
              data : string : 加密数据
    params: headers : 请求头
    ====================返回======================
    """
    _method = "POST"
    _url = "/open/haohan/rights/update"

    _headers = {
        "Content-Type": "application/json",
    }
    _headers.update({"headers": headers})

    _data = {
        "params": params,
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/open/haohan/rights/update")
def open_haohan_rights_update(params=None, headers=None, **kwargs):
    """
    浩瀚模块 - 更改充电桩权益状态-Y
    up_time=1675665629

    params: params : object : 
              data : string : 加密数据
    params: headers : 请求头
    ====================返回======================
    """
    _method = "POST"
    _url = "/open/haohan/rights/update"

    _headers = {
        "Content-Type": "application/json",
    }
    _headers.update({"headers": headers})

    _data = {
        "params": params,
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/open/haohan/rights/update")
def open_haohan_rights_update(params=None, headers=None, **kwargs):
    """
    浩瀚模块 - 更改充电桩权益状态-Y
    up_time=1675665629

    params: params : object : 
              data : string : 加密数据
    params: headers : 请求头
    ====================返回======================
    """
    _method = "POST"
    _url = "/open/haohan/rights/update"

    _headers = {
        "Content-Type": "application/json",
    }
    _headers.update({"headers": headers})

    _data = {
        "params": params,
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/open/haohan/rights/update")
def open_haohan_rights_update(params=None, headers=None, **kwargs):
    """
    浩瀚模块 - 更改充电桩权益状态-Y
    up_time=1675665629

    params: params : object : 
              data : string : 加密数据
    params: headers : 请求头
    ====================返回======================
    """
    _method = "POST"
    _url = "/open/haohan/rights/update"

    _headers = {
        "Content-Type": "application/json",
    }
    _headers.update({"headers": headers})

    _data = {
        "params": params,
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/open/haohan/rights/update")
def open_haohan_rights_update(params=None, headers=None, **kwargs):
    """
    浩瀚模块 - 更改充电桩权益状态-Y
    up_time=1675665629

    params: params : object : 
              data : string : 加密数据
    params: headers : 请求头
    ====================返回======================
    """
    _method = "POST"
    _url = "/open/haohan/rights/update"

    _headers = {
        "Content-Type": "application/json",
    }
    _headers.update({"headers": headers})

    _data = {
        "params": params,
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/open/haohan/rights/update")
def open_haohan_rights_update(params=None, headers=None, **kwargs):
    """
    浩瀚模块 - 更改充电桩权益状态-Y
    up_time=1675665629

    params: params : object : 
              data : string : 加密数据
    params: headers : 请求头
    ====================返回======================
    """
    _method = "POST"
    _url = "/open/haohan/rights/update"

    _headers = {
        "Content-Type": "application/json",
    }
    _headers.update({"headers": headers})

    _data = {
        "params": params,
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/open/haohan/rights/update")
def open_haohan_rights_update(params=None, headers=None, **kwargs):
    """
    浩瀚模块 - 更改充电桩权益状态-Y
    up_time=1675665629

    params: params : object : 
              data : string : 加密数据
    params: headers : 请求头
    ====================返回======================
    """
    _method = "POST"
    _url = "/open/haohan/rights/update"

    _headers = {
        "Content-Type": "application/json",
    }
    _headers.update({"headers": headers})

    _data = {
        "params": params,
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/open/haohan/rights/update")
def open_haohan_rights_update(params=None, headers=None, **kwargs):
    """
    浩瀚模块 - 更改充电桩权益状态-Y
    up_time=1675665629

    params: params : object : 
              data : string : 加密数据
    params: headers : 请求头
    ====================返回======================
    """
    _method = "POST"
    _url = "/open/haohan/rights/update"

    _headers = {
        "Content-Type": "application/json",
    }
    _headers.update({"headers": headers})

    _data = {
        "params": params,
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/open/haohan/rights/update")
def open_haohan_rights_update(params=None, headers=None, **kwargs):
    """
    浩瀚模块 - 更改充电桩权益状态-Y
    up_time=1675665629

    params: params : object : 
              data : string : 加密数据
    params: headers : 请求头
    ====================返回======================
    """
    _method = "POST"
    _url = "/open/haohan/rights/update"

    _headers = {
        "Content-Type": "application/json",
    }
    _headers.update({"headers": headers})

    _data = {
        "params": params,
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/open/haohan/rights/update")
def open_haohan_rights_update(params=None, headers=None, **kwargs):
    """
    浩瀚模块 - 更改充电桩权益状态-Y
    up_time=1675665629

    params: params : object : 
              data : string : 加密数据
    params: headers : 请求头
    ====================返回======================
    """
    _method = "POST"
    _url = "/open/haohan/rights/update"

    _headers = {
        "Content-Type": "application/json",
    }
    _headers.update({"headers": headers})

    _data = {
        "params": params,
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/open/haohan/rights/update")
def open_haohan_rights_update(params=None, headers=None, **kwargs):
    """
    浩瀚模块 - 更改充电桩权益状态-Y
    up_time=1675665629

    params: params : object : 
              data : string : 加密数据
    params: headers : 请求头
    ====================返回======================
    """
    _method = "POST"
    _url = "/open/haohan/rights/update"

    _headers = {
        "Content-Type": "application/json",
    }
    _headers.update({"headers": headers})

    _data = {
        "params": params,
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/open/haohan/rights/update")
def open_haohan_rights_update(params=None, headers=None, **kwargs):
    """
    浩瀚模块 - 更改充电桩权益状态-Y
    up_time=1675665629

    params: params : object : 
              data : string : 加密数据
    params: headers : 请求头
    ====================返回======================
    """
    _method = "POST"
    _url = "/open/haohan/rights/update"

    _headers = {
        "Content-Type": "application/json",
    }
    _headers.update({"headers": headers})

    _data = {
        "params": params,
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/open/haohan/rights/update")
def open_haohan_rights_update(params=None, headers=None, **kwargs):
    """
    浩瀚模块 - 更改充电桩权益状态-Y
    up_time=1675665629

    params: params : object : 
              data : string : 加密数据
    params: headers : 请求头
    ====================返回======================
    """
    _method = "POST"
    _url = "/open/haohan/rights/update"

    _headers = {
        "Content-Type": "application/json",
    }
    _headers.update({"headers": headers})

    _data = {
        "params": params,
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/open/haohan/rights/update")
def open_haohan_rights_update(params=None, headers=None, **kwargs):
    """
    浩瀚模块 - 更改充电桩权益状态-Y
    up_time=1675665629

    params: params : object : 
              data : string : 加密数据
    params: headers : 请求头
    ====================返回======================
    """
    _method = "POST"
    _url = "/open/haohan/rights/update"

    _headers = {
        "Content-Type": "application/json",
    }
    _headers.update({"headers": headers})

    _data = {
        "params": params,
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/open/haohan/rights/update")
def open_haohan_rights_update(params=None, headers=None, **kwargs):
    """
    浩瀚模块 - 更改充电桩权益状态-Y
    up_time=1675665629

    params: params : object : 
              data : string : 加密数据
    params: headers : 请求头
    ====================返回======================
    """
    _method = "POST"
    _url = "/open/haohan/rights/update"

    _headers = {
        "Content-Type": "application/json",
    }
    _headers.update({"headers": headers})

    _data = {
        "params": params,
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/open/haohan/rights/update")
def open_haohan_rights_update(params=None, headers=None, **kwargs):
    """
    浩瀚模块 - 更改充电桩权益状态-Y
    up_time=1675665629

    params: params : object : 
              data : string : 加密数据
    params: headers : 请求头
    ====================返回======================
    """
    _method = "POST"
    _url = "/open/haohan/rights/update"

    _headers = {
        "Content-Type": "application/json",
    }
    _headers.update({"headers": headers})

    _data = {
        "params": params,
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/open/haohan/rights/update")
def open_haohan_rights_update(params=None, headers=None, **kwargs):
    """
    浩瀚模块 - 更改充电桩权益状态-Y
    up_time=1675665629

    params: params : object : 
              data : string : 加密数据
    params: headers : 请求头
    ====================返回======================
    """
    _method = "POST"
    _url = "/open/haohan/rights/update"

    _headers = {
        "Content-Type": "application/json",
    }
    _headers.update({"headers": headers})

    _data = {
        "params": params,
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/open/haohan/rights/update")
def open_haohan_rights_update(params=None, headers=None, **kwargs):
    """
    浩瀚模块 - 更改充电桩权益状态-Y
    up_time=1675665629

    params: params : object : 
              data : string : 加密数据
    params: headers : 请求头
    ====================返回======================
    """
    _method = "POST"
    _url = "/open/haohan/rights/update"

    _headers = {
        "Content-Type": "application/json",
    }
    _headers.update({"headers": headers})

    _data = {
        "params": params,
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/open/haohan/rights/update")
def open_haohan_rights_update(params=None, headers=None, **kwargs):
    """
    浩瀚模块 - 更改充电桩权益状态-Y
    up_time=1675665629

    params: params : object : 
              data : string : 加密数据
    params: headers : 请求头
    ====================返回======================
    """
    _method = "POST"
    _url = "/open/haohan/rights/update"

    _headers = {
        "Content-Type": "application/json",
    }
    _headers.update({"headers": headers})

    _data = {
        "params": params,
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/open/haohan/rights/update")
def open_haohan_rights_update(params=None, headers=None, **kwargs):
    """
    浩瀚模块 - 更改充电桩权益状态-Y
    up_time=1675665629

    params: params : object : 
              data : string : 加密数据
    params: headers : 请求头
    ====================返回======================
    """
    _method = "POST"
    _url = "/open/haohan/rights/update"

    _headers = {
        "Content-Type": "application/json",
    }
    _headers.update({"headers": headers})

    _data = {
        "params": params,
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/open/haohan/rights/update")
def open_haohan_rights_update(params=None, headers=None, **kwargs):
    """
    浩瀚模块 - 更改充电桩权益状态-Y
    up_time=1675665629

    params: params : object : 
              data : string : 加密数据
    params: headers : 请求头
    ====================返回======================
    """
    _method = "POST"
    _url = "/open/haohan/rights/update"

    _headers = {
        "Content-Type": "application/json",
    }
    _headers.update({"headers": headers})

    _data = {
        "params": params,
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/open/haohan/rights/update")
def open_haohan_rights_update(params=None, headers=None, **kwargs):
    """
    浩瀚模块 - 更改充电桩权益状态-Y
    up_time=1675665629

    params: params : object : 
              data : string : 加密数据
    params: headers : 请求头
    ====================返回======================
    """
    _method = "POST"
    _url = "/open/haohan/rights/update"

    _headers = {
        "Content-Type": "application/json",
    }
    _headers.update({"headers": headers})

    _data = {
        "params": params,
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)





from huhk import projects_path, admin_host
from huhk.unit_dict import Dict


class ProjectInIt:
    def __init__(self, name=None, app_key=None, yapi_url=None, yapi_token=None, yapi_json_file=None, swagger_url=None):
        """api_type: 0时，value是swagger的api，json的url
                     1时，value值为yapi项目token,
                     2时，value是yapi下载的json文件名，文件放在file目录下,
                     3时，value是yapi的yapi-swagger.json
           name:项目名称，空时默认当前py文件所在文件名上级目录
        """
        self.path = Dict()
        self.path.dir = projects_path
        self.app_key = app_key
        self.name = name
        self.yapi_url = yapi_url
        self.yapi_token = yapi_token
        self.yapi_json_file = yapi_json_file
        self.swagger_url = swagger_url
        self.url = admin_host
        self.yapi_file_str = None
        self.size_names = ("pagesize", "size", "limit")
        self.page_names = ("pageNum", "current", "currentpage")
        self.before = ("before", "start")
        self.end = ("end", )
        self.page_and_size = self.size_names + self.page_names


        self.api_testcase_list = []
        self.api_testcase_file_str = ""
        self.sql_fun_list = None
        self.name2 = None
        self.api_fun_fun_list = None
        self.api_fun_file_str = None
        self.assert_fun_list = None
        self.assert_file_str = None
        self.sql_file_str = None
        self.sql_file_str = None
        self.fun_init_list = None
        self.fun_init_str = None
        self.fun_file_str = None
        self.api_file_str = ""

        self.yapi_url = yapi_url
        self.api_type = None
        self.app_key = app_key
        self.name = name
        self.name2 = name
        self.api_list_old = []
        self.api_list = Dict()
        self.error = ""
        self.this_file_list = Dict({"api": [], "fun": [], "assert": [], "sql": []})
        self.this_fun_list = Dict()
        self.this_api_fun = Dict()



import json
import os.path
import re
import sys
import requests
import time

from huhk.case_project.project_base import ProjectBase
from huhk.unit_dict import Dict
from huhk.unit_fun import FunBase
from huhk import projects_path


class GetApi(ProjectBase):
    def __init__(self, name=None, app_key=None, yapi_url=None, yapi_token=None, yapi_json_file=None, swagger_url=None):
        """
        """
        super().__init__(name, app_key, yapi_url, yapi_token, yapi_json_file, swagger_url)
        self.get_project()

    def create_or_update_project(self, _update=False):
        """
        创建项目
        """
        # 创建项目目录
        self.set_file_path()
        # 获取已维护api方法接口列表
        self.get_this_fun_list()
        # 获取接口文档api接口列表
        self.get_api_list()
        # 添加api封装方法
        self.write_fun(_update=_update)

    def set_file_path(self):
        """创建项目框架"""
        FunBase.mkdir_file(self.path.values(), is_py=True)
        if not os.path.exists(os.path.join(self.path.service_dir, "__init__.py")) or \
                not FunBase.read_file(os.path.join(self.path.service_dir, "__init__.py")):
            FunBase.write_file(os.path.join(self.path.service_dir, "__init__.py"), value=self.get_init_value())
        if not os.path.exists(os.path.join(self.path.service_dir, f"{self.name}_fun.py")):
            FunBase.write_file(os.path.join(self.path.service_dir, f"{self.name}_fun.py"), value=self.get_fun_value())

    def get_api_fun_list(self):
        """获取已维护方法列表，无则创建demo文件"""
        self.path.fun_file_path = os.path.join(self.path.service_dir, self.name + "_fun.py")
        if os.path.exists(self.path.fun_file_path):
            self.fun_file_str = FunBase.read_file(self.path.fun_file_path)
        else:
            self.fun_file_str = "import requests\n\nfrom huhk.unit_fun import FunBase\n" \
                                "from huhk import admin_host\n\n\nclass %sFun(FunBase):\n" \
                                "    def __init__(self):\n        super().__init__()\n        self.res = None\n\n" \
                                "    def run_mysql(self, sql_str):\n" \
                                "        # id是后台http://47.96.124.102/admin 项目数据库链接的id\n" \
                                '        out = requests.post(admin_host + "/sql/running_sql/", ' \
                                'json={"id": 1, "sql_str": sql_str}).json()\n' \
                                '        if out.get("code") == "0000":\n' \
                                '            return out.get("data")\n        else:\n' \
                                '            assert False, sql_str + str(out.get("msg"))\n\n\n' \
                                "if __name__ == '__main__':\n    f = %sFun()\n" \
                                '    out = f.run_mysql("SELECT * FROM `t_accept_log`  LIMIT 1;")\n' \
                                '    print(out)\n\n' % (self.name2, self.name2)
        self.fun_init_str = re.findall(r"(def +[\d\D]*?\n)\s*def", self.fun_file_str)[0]
        self.fun_init_list = [i.split('=')[0].strip()[5:] for i in self.fun_init_str.split('\n') if "=" in i]

        self.path.sql_file_path = os.path.join(self.path.service_dir, self.name + "_sql.py")
        if os.path.exists(self.path.sql_file_path):
            self.sql_file_str = FunBase.read_file(self.path.sql_file_path)
        else:
            self.sql_file_str = "from service.%s.%s_fun import %sFun\n\n\n" % (self.name, self.name, self.name2)
            self.sql_file_str += "class %sSql(%sFun):\n\n\n" \
                                 "if __name__ == '__main__':\n    s = %sSql()\n\n" % (
                                     self.name2, self.name2, self.name2)
        self.sql_fun_list = re.findall("    def +(.*)?\(", self.sql_file_str)

        self.path.assert_file_path = os.path.join(self.path.service_dir, self.name + "_assert.py")
        if os.path.exists(self.path.assert_file_path):
            self.assert_file_str = FunBase.read_file(self.path.assert_file_path)
        else:
            self.assert_file_str = "import allure\n\nfrom service.%s.%s_sql import %sSql\n\n\n" % (
            self.name, self.name, self.name2)
            self.assert_file_str += "class %sAssert(%sSql):\n\n\n" \
                                    "if __name__ == '__main__':\n    s = %sAssert()\n\n" % (
                                        self.name2, self.name2, self.name2)
        self.assert_fun_list = re.findall("    def +(.*)?\(", self.assert_file_str)

        self.path.api_fun_file_path = os.path.join(self.path.service_dir, self.name + "_api_fun.py")
        if os.path.exists(self.path.api_fun_file_path):
            self.api_fun_file_str = FunBase.read_file(self.path.api_fun_file_path)
        else:
            self.api_fun_file_str = "from service.%s.%s_assert import %sAssert\n" % (self.name, self.name, self.name2)
            self.api_fun_file_str += "from service.%s import %s_api\n\nimport allure\n" % (self.name, self.name)
            self.api_fun_file_str += "\n\nclass %sApiFun(%sAssert):\n\n" \
                                     "if __name__ == '__main__':\n    s = %sApiFun()\n\n" % (
                                         self.name2, self.name2, self.name2)
        self.api_fun_fun_list = re.findall("    def +(.*)?\(", self.api_fun_file_str)

        self.path.api_testcase_file_path = os.path.join(self.path.testcase_dir, "test_api.py")
        if os.path.exists(self.path.api_testcase_file_path):
            self.api_testcase_file_str = FunBase.read_file(self.path.api_testcase_file_path)
        else:
            self.api_testcase_file_str = "import pytest\nimport allure\n\n" \
                                         "from service.%s.%s_api_fun import %sApiFun\n\n\n" % (
                                             self.name, self.name, self.name2)
            self.api_testcase_file_str += '@allure.epic("针对单api的测试")\n@allure.feature("场景：")\nclass TestApi:\n' \
                                          '    def setup(self):\n        self.f = %sApiFun()\n\n' % self.name2
        self.api_testcase_list = re.findall("    def +test_(.*)?\(", self.api_testcase_file_str)

    def get_api_list(self):
        """根据api文档不同方式生成api文件"""
        if self.swagger_url:
            self.get_list_menu_swagger()
        elif self.yapi_url and self.yapi_token:
            self.get_list_menu()
        elif self.yapi_file_str or self.yapi_json_file:
            self.get_list_json()

    def write_fun(self, _update=False):
        if not self.this_fun_list.api and not self.api_list:
            self.api_list += [{'method': 'GET', 'title': '示例-get', 'path': '/demo/get', 'up_time': 1675665418},
                              {'method': 'POST', 'title': '示例-post', 'path': '/demo/post', 'up_time': 1675665418}]
        for row in self.api_list:
            self.write_api(row)
        for fun_name in self.this_fun_list.api.keys():
            self.write_sql(fun_name, _update=_update)
            self.write_assert(fun_name, _update=_update)
            self.write_api_fun(fun_name, _update=True)

    def write_api_fun2(self):
        for row in self.api_list:
            fun_name = self.get_fun_name(row.get('path'))
            if fun_name in self.api_list_old:
                ord_str = re.findall(r'(def %s\(.+\)[\w\W]*?)(def|$)' % fun_name, self.api_file_str)
                up_time = re.findall(r'up_time=(\d+)([\w\W]+)', ord_str[0][0])
                if up_time and int(up_time[0][0]) < row.get('up_time'):
                    new_str = self.get_api_fun_str(fun_name, row)
                    self.api_file_str = self.api_file_str.replace(ord_str[0][0], new_str)
            else:
                self.api_list_old.append(fun_name)
                self.api_file_str += self.get_api_fun_str(fun_name, row)
        if not self.api_list_old:
            self.api_list_old.append("demo")
            self.api_file_str += """@allure.step(title="调接口：/demo")\ndef demo(mobile=None, headers=None, **kwargs):
    \"""\n    发送手机验证码\n    up_time=1657087679\n\n    params: mobile :  : 用户电话号码
    params: headers : 请求\n    ====================返回======================
    params: code : number : \n    params: msg : string : \n    params: data : null : 
    \"""\n    _method = "GET"\n    _url = "/common/common/sendSmsCode"\n
    _headers = {\n        "Content-Type": "application/x-www-form-urlencoded",\n    }
    _headers.update({"headers": headers})\n\n    _data = {\n        "mobile": mobile,  # 用户电话号码\n    }\n
    _params = {\n    }\n
    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)\n\n"""
        for fun_name in self.api_list_old:
            if fun_name not in self.api_fun_fun_list:
                self.api_fun_fun_list.append(fun_name)
                self.get_api_fun_fun_str(fun_name)
        for fun_name in self.api_fun_fun_list:
            if "assert_" + fun_name not in self.assert_fun_list and "self.assert_" + fun_name + '(' in self.api_fun_file_str:
                self.assert_fun_list.append("assert_" + fun_name)
                self.get_assert_fun_str(fun_name)
        for fun_name in self.assert_fun_list:
            fun_name = fun_name[7:]
            if "sql_" + fun_name not in self.sql_fun_list and "self.sql_" + fun_name + '(' in self.assert_file_str:
                self.sql_fun_list.append("sql_" + fun_name)
                self.get_sql_fun_str(fun_name)
        for fun_name in self.api_fun_fun_list:
            if fun_name not in self.api_testcase_list:
                self.api_testcase_list.append("test_" + fun_name)
                self.get_api_testcase_str(fun_name)

        FunBase.write_file(self.path.api_file_path, self.api_file_str)
        FunBase.write_file(self.path.fun_file_path, self.fun_file_str)
        FunBase.write_file(self.path.sql_file_path, self.sql_file_str)
        FunBase.write_file(self.path.assert_file_path, self.assert_file_str)
        FunBase.write_file(self.path.api_fun_file_path, self.api_fun_file_str)
        FunBase.write_file(self.path.api_testcase_file_path, self.api_testcase_file_str)


    def get_api_testcase_str(self, fun_name):
        api_fun_str = re.findall(r'(def %s\(.+\)[\w\W]*?)(def |$)' % fun_name, self.api_file_str)
        if api_fun_str:
            api_fun_str = api_fun_str[0][0]
        else:
            return False
        desc = re.findall(r'"""([\w\W]*)"""', api_fun_str)
        api_testcase_str = '    @pytest.mark.skip("待维护")\n'
        if desc:
            desc = desc[0].split('====================返回======================')[0]
            desc_list = [" " * 8 + i.strip() for i in desc.split('\n') if "up_time=" not in i and i.strip()
                         and "params: headers" not in i]
            api_testcase_str += '    @allure.step(title="%s")\n' % (
                desc_list[0].strip() if desc_list else "")
        api_testcase_str += '    def test_%s(self):\n        self.f.%s()\n\n\n' % (fun_name, fun_name)
        self.api_testcase_file_str += api_testcase_str

    # def get_assert_fun_str(self, fun_name):
    #     data = re.findall(r'def %s\((.*)?\)' % fun_name, self.api_fun_file_str)[0]
    #     data_list = [i.split('=')[0].strip() for i in data.split(',') if len(i.split('=')) > 1
    #                  and i.strip()[0] != '_' and i.split('=')[0].strip() != "headers"]
    #     assert_fun_str = '    @allure.step(title="接口返回结果校验")\n    def assert_%s(self, **kwargs):\n' \
    #                      '        assert self.res.rsp.code in (0, 200), self.res.rsp.msg\n' \
    #                      '        # out = self.sql_%s(**kwargs)\n' % (fun_name, fun_name)
    #     assert_fun_str += '        # flag = self.compare_json_list(self.res, out, [%s])\n' % \
    #                       ', '.join(['"%s"' % i for i in data_list if i not in self.page_and_size])
    #     assert_fun_str += '        assert True, "数据比较不一致"\n\n'
    #     assert_file_str_tmp = re.split(r"(\nif __name__ == '__main__':)", self.assert_file_str)
    #     assert_file_str_tmp.insert(1, assert_fun_str)
    #     self.assert_file_str = "".join(assert_file_str_tmp)

    def sub_hz(self, _id, _str):
        if re.findall(r'[^\da-zA-Z_\ (=,*):]', re.findall(r"def .*?\):", _str)[0]):
            api = self.get_api(_id)
            tmp2 = api.get('data', {}).get('req_params', [])
            for tmp3 in tmp2:
                name = tmp3.get('name', "")
                desc = tmp3.get('desc', "")
                if re.findall(r'[^\da-zA-Z_\ (=,*):]', name) and not re.findall(r'\W', desc):
                    _str = _str.replace(name, desc)
        if re.findall(r'[( ]async[,=)]', _str):
            for tmp in re.findall(r'[( ]async[,=)]', _str):
                tmp1 = str(tmp).replace('async', 'async1')
                _str = _str.replace(tmp, tmp1)
        return _str

    @staticmethod
    def get_main_key():
        return GetApi._get_service_value("this_key", _type=1)

    @staticmethod
    def set_main_key(value):
        GetApi._set_service_value("this_key", value, _type=1)
        return True

    @staticmethod
    def get_main_name():
        return GetApi._get_service_value("this_name", _type=1)

    @staticmethod
    def set_main_name(value):
        GetApi._set_service_value("this_name", value, _type=1)

    @staticmethod
    def get_key_name_list():
        out = Dict()
        for dirpath, dirnames, filenames in os.walk(projects_path):
            for filename in filenames:
                if "__init__.py" in filename:
                    out[1] = 1
        return True


if __name__ == '__main__':
    ga = GetApi()
    print('--key：', ga.get_main_name())


from huhk.case_project.version import version as _version
from huhk.init_project import GetApi


def get_version():
    k = str(GetApi.get_main_key())
    v = str(GetApi.get_main_name())
    out_str = f"版本：{_version}\n--key：{k}\n--name：{v}"
    return out_str


def set_key_name(key, name):
    if key and name:
        GetApi.set_main_key(key)
        GetApi.set_main_name(name)
    elif key or name:
        key_list = GetApi.get_key_name_list()
    return True


from service.app_t.funs.open.haohan.funs_open_haohan_relation import FunsOpenHaohanRelation
from service.app_t.funs.open.haohan.funs_open_haohan_rights import FunsOpenHaohanRights


class FunsOpenHaohan(FunsOpenHaohanRelation, FunsOpenHaohanRights):
    pass




from huhk.unit_apache_beam import ApacheFun


class TestMap:
    # 带有预定义函数的 FlatMap
    def test_map_001(self):
        ApacheFun(data_list_str3, data_type=data_type).map(str.strip).print()

    # 带有lambda函数的Map
    def test_map_002(self):
        ApacheFun(data_list_str3, data_type=data_type).map(lambda x: x.strip('# \n')).print()

    def test_map_003(self):
        ApacheFun(data_list_tuple, data_type=data_type).map_tuple(lambda icon, plant: '{}{}'.format(icon, plant)).print()


import allure

from service.app_t import unit_request
from service.app_t.sqls.open.haohan.sqls_open_haohan_relation import SqlsOpenHaohanRelation


class AssertsOpenHaohanRelation(SqlsOpenHaohanRelation):
    @allure.step(title="接口返回结果校验")
    def assert_open_haohan_relation_update(self, **kwargs):
        assert unit_request.is_assert_true(self.res), "校验接口返回，缺少成功标识"
        # out = self.sql_open_haohan_relation_update(**kwargs)
        # flag = self.compare_json_list(self.res, out, ["userId"])
        assert True, "数据比较不一致"




from service.app_t.funs.points.funs_points_pointsApp import FunsPointsPointsapp
from service.app_t.funs.points.funs_points_points import FunsPointsPoints


class FunsPoints(FunsPointsPointsapp, FunsPointsPoints):
    pass




import click
from huhk.case_project.main_fun import get_version, set_key_name


@click.command()
@click.option('-v', '--version', help='版本, 当前--key/--name', is_eager=True, is_flag=True)
@click.option('-k', '--key', help='项目key, 传*表示所有项目，不传默认去上一次key', multiple=True)
@click.option('-n', '--name', help='项目名称, 传*表示所有项目，不传默认去上一次name', multiple=True)
@click.option('-i', '--install', help='根据key创建项目, 项目存在则更新')
@click.option('-u', '--update', help='根据--key更新项目，--key不存在时默认取之前的值', is_eager=True, is_flag=True)
@click.option('-f', '--fun', help='新增api方法，参数url，--key不存在时默认取之前的值', multiple=True)
def main(version, key, name, install, update, fun):
    print(version, key, name, install, update, fun)
    if version:
        click.echo(get_version())
    else:
        set_key_name(key, name)

    # for k in key:
    #     if install:
    #         click.echo('init：' + _version)
    #         click.echo(type(install))
    #     elif update:
    #         click.echo('update：' + _version)
    #         click.echo(type(update))


if __name__ == '__main__':
    main()


import allure

from service.app_t.asserts.points.asserts_points_pointsApp import AssertsPointsPointsapp
from service.app_t.apis.points import apis_points_pointsApp


class FunsPointsPointsapp(AssertsPointsPointsapp):
    @allure.step(title="APP-用户签到")
    def points_pointsApp_signIn(self, userId="$None$", _assert=True,  **kwargs):
        """
            url=/points/pointsApp/signIn
                params: headers : 请求头
        """
        userId = self.get_value_choice(userId, list_or_dict=None, key=None)
        _kwargs = self.get_kwargs(locals())
        self.res = apis_points_pointsApp.points_pointsApp_signIn(**_kwargs)

        self.assert_points_pointsApp_signIn(_assert, **_kwargs)
        self.set_value(_kwargs)


    @allure.step(title="APP - 查看我的积分")
    def points_pointsApp_myPoints(self, userId="$None$", _assert=True,  **kwargs):
        """
            url=/points/pointsApp/myPoints
                params: headers : 请求头
        """
        userId = self.get_value_choice(userId, list_or_dict=None, key=None)
        _kwargs = self.get_kwargs(locals())
        self.res = apis_points_pointsApp.points_pointsApp_myPoints(**_kwargs)

        self.assert_points_pointsApp_myPoints(_assert, **_kwargs)
        self.set_value(_kwargs)


    @allure.step(title="APP - 总积分查询")
    def points_pointsApp_myPointsTotal(self, userId="$None$", _assert=True,  **kwargs):
        """
            url=/points/pointsApp/myPointsTotal
                params: headers : 请求头
        """
        userId = self.get_value_choice(userId, list_or_dict=None, key=None)
        _kwargs = self.get_kwargs(locals())
        self.res = apis_points_pointsApp.points_pointsApp_myPointsTotal(**_kwargs)

        self.assert_points_pointsApp_myPointsTotal(_assert, **_kwargs)
        self.set_value(_kwargs)





import json
import os
import re

import requests

from huhk.case_project.project_init import ProjectInIt
from huhk.unit_dict import Dict


class ProjectString(ProjectInIt):
    def _get_description(self, req_body_other):
        try:
            if not req_body_other:
                return []
            elif isinstance(req_body_other, str):
                properties = json.loads(req_body_other).get('properties') or {}
            elif isinstance(req_body_other, list):
                return req_body_other
            else:
                properties = req_body_other.get('properties') if req_body_other.get('properties') else req_body_other
            _list = []
            for k, v in properties.items():
                if type(v) == dict:
                    _properties = self._get_description(v.get('properties')) if v.get('properties') else None
                    _items = self._get_description(v.get('items')) if v.get('items') else None
                    _row = {"name": k,
                            "desc": v.get('description', ""),
                            "type": v.get('type', ""),
                            "properties": _properties,
                            "items": _items}
                else:
                    _row = {"name": k,
                            "desc": None,
                            "type": v,
                            "properties": None,
                            "items": None}
                _list.append(_row)
            return _list
        except Exception as e:
            print(e)

    def get_init_value(self):
        """
            生成项目__init__.py文件
        """
        value = 'from huhk.init_project import GetApi\n'
        value += 'from huhk.unit_request import UnitRequest\n\n\n'
        value += 'class Request(UnitRequest):\n    pass\n\n\n'
        value += f'APP_KEY = "{self.app_key}"\n\n\n' if self.app_key else ""
        value += 'unit_request = Request("SIT", APP_KEY)\n'
        value += '# 环境变量\nvariable = unit_request.variable\n'
        value += 'http_requester = unit_request.http_requester\n\n\n'
        value += 'if __name__ == "__main__":\n'
        value += f"    GetApi(name='{self.name}'"
        if self.app_key:
            value += f", app_key=APP_KEY"
        elif self.yapi_url and self.yapi_token:
            value += f", yapi_url='{self.yapi_url}', yapi_token='{self.yapi_token}'"
        elif self.yapi_json_file:
            value += f", yapi_json_file='{self.yapi_json_file}'"
        elif self.swagger_url:
            value += f", swagger_url='{self.swagger_url}'"
        value += ").create_or_update_project()\n"
        return value

    def get_fun_value(self):
        """生成项目基础方法"""
        value = "import requests\n\nfrom huhk.unit_fun import FunBase\n"
        value += "from huhk.unit_dict import Dict\n"
        value += f"from huhk import admin_host\n\n\nclass {self.name2.replace('_', '')}Fun(FunBase):\n"
        value += "    def __init__(self):\n        super().__init__()\n        self.res = None\n"
        value += "        self.output_list = Dict()\n        self.input_value = Dict()\n"
        value += "    @staticmethod\n    def run_mysql( sql_str, db_id=1):\n"
        value += "        # 根据后台数据库配置id查询\n"
        value += '        out = requests.post(admin_host + "/sql/running_sql/", '
        value += 'json={"id": db_id, "sql_str": sql_str}).json()\n'
        value += '        if out.get("code") == "0000":\n'
        value += '            return out.get("data")\n        else:\n'
        value += '            assert False, sql_str + str(out.get("msg"))\n\n\n'
        value += f"if __name__ == '__main__':\n    f = {self.name2.replace('_', '')}Fun()\n"
        value += '    out = f.faker().name()\n'
        value += '    print(out)\n\n'
        return value

    @staticmethod
    def get_params_string(req_all, res_body):
        """方法描述生成"""
        def get_str(l):
            _str = ""
            for p in l:
                _str += f'    params: {p.get("name", "")} : {p.get("type", "")} : {p.get("desc", "")}\n'
                if p.get('properties') or p.get('items'):
                    for p2 in p.get('properties') or p.get('items'):
                        _str += f'              {p2.get("name", "")} : {p2.get("type", "")} : {p2.get("desc", "")}\n'
            return _str

        try:
            api_str = get_str(req_all)
            api_str += "    params: headers : 请求头\n    ====================返回======================\n"
            api_str += get_str(res_body)
            return api_str
        except Exception as e:
            print(e)

    @staticmethod
    def list_add(_list):
        """列表变量叠加"""
        _list3 = []
        _list4 = ["Content-Type"]
        for i in _list:
            name = i.get("name").split("[")[0]
            if name not in _list4:
                _list4.append(name)
                i["name"] = name
                _list3.append(i)
        return _list3

    @staticmethod
    def get_req_json(_list, value=False):
        """"""
        json_str = '{\n'
        for p in _list:
            json_str += f'        "{p.get("name", "")}": ' + (
                '"%s"' % p.get("value", "") if value else p.get("name", "")) + ","
            json_str += ("  # " + p.get("desc").replace('\n', ' ') if p.get("desc") else "") + '\n'
        json_str += '    }'
        return json_str

    @staticmethod
    def get_fun_name(name):
        name = re.sub(r'\W', '_', name.split('{')[0]).strip().lstrip('_')
        return name

    def get_path(self, name, fun_type="apis"):
        name_l = [i for i in name.split('_') if i]
        out = Dict()
        if fun_type == "api" and self.this_fun_list.api[name]:
            filename = self.this_fun_list.api[name].path
            out.path = filename
            out.class_name = None
            out.import_path = ".".join(filename.replace(self.path.dir, "").split(os.sep)[1:])[:-3]
        else:
            filename = f"{fun_type}_{'_'.join(name_l[:-1]) if name_l[:-1] else self.name}.py".replace('__', "_")
            out.path = os.path.join(self.path.service_dir, fun_type, os.path.sep.join(name_l[:-2]), filename)
            out.class_name = filename.split(".")[0].title().replace('_', '')
            out.import_path = ".".join(["service", self.name, fun_type] + name_l[:-2] + [filename.split('.py')[0]])
        return out

    def get_api_header_str(self):
        api_header_str = f"import allure\n\nfrom service.{self.name} import http_requester\n" \
                         f"from huhk.unit_request import get_url\n\n\n"
        return api_header_str

    def get_api_fun_str(self, name, row):
        if self.api_type == 1:
            data = {"token": self.yapi_token, "id": row.get('_id')}
            res = requests.get(self.yapi_url + "/api/interface/get", data=data)
            row = Dict(json.loads(res.text)).get('data')
        api_str = '@allure.step(title="调接口：%s")\n' % row.get("path").split('{')[0]
        api_str += "def " + name + "("
        req_params = row.get('req_params', [])
        req_query = row.get('req_query', [])
        req_body_form = row.get('req_body_form', [])
        req_headers = row.get('req_headers', [])
        req_body = self._get_description(row.get('req_body_other'))
        res_body = self._get_description(row.get('res_body'))
        req_all = self.list_add(req_params + req_query + req_body_form + req_body)
        req_all_data = self.list_add(req_query + req_body_form + req_body)

        api_str += " ".join(set([i.get('name') + '=None,' for i in req_all])) + " headers=None, **kwargs):\n"
        api_str += f'    """\n    {row["title"]}\n    up_time={row["up_time"]}\n\n'
        api_str += self.get_params_string(req_all, res_body)
        api_str += f'    """\n    _method = "{row.get("method")}"\n    _url = "{row.get("path")}"\n'
        if '/{' in row.get("path"):
            api_str += f'    _url = get_url(_url, locals())\n'
        api_str += '\n    _headers = ' + self.get_req_json(req_headers, True)
        api_str += '\n    _headers.update({"headers": headers})\n\n'
        api_str += '    _data = ' + self.get_req_json(req_all_data)
        api_str += '\n\n    _params = ' + self.get_req_json(req_params)
        api_str += '\n\n    return http_requester(_method, _url, params=_params, data=_data, ' \
                   'headers=_headers, **kwargs)\n\n\n'
        return api_str

    def get_sql_header_str(self, class_name):
        header_str = f"from service.{self.name}.{self.name}_fun import {self.name2.replace('_', '')}Fun\n\n\n"
        header_str += f"class {class_name}({self.name2.replace('_', '')}Fun):\n"
        return header_str

    @staticmethod
    def get_sql_fun_str(fun_name):
        sql_fun_str = "    def sql_%s(self, **kwargs):\n" % fun_name
        sql_fun_str += "        # name = self.kwargs_pop(kwargs, 'name')  # 单独处理字段\n"
        sql_fun_str += "        # self.kwargs_replace(kwargs, likes=[], ins=[], before_end=[])  "
        sql_fun_str += "# 模糊查询字段，数组包含查询字段，区间字段处理\n"
        sql_fun_str += '        # kwargs["order_by"] = None  # 排序\n'
        sql_fun_str += '        sql_str = self.get_sql_str("table_name", **kwargs)  # 生成sql语句\n'
        sql_fun_str += '        # out = self.run_mysql(sql_str)  # 执行sql语句\n' \
                       '        # return out\n\n'
        return sql_fun_str

    def get_assert_header_str(self, class_name, sql_path):
        header_str = f"import allure\n\n"
        header_str += f"from service.{self.name} import unit_request\n"
        header_str += f"from {sql_path.import_path} import {sql_path.class_name}\n\n\n"
        header_str += f"class {class_name}({sql_path.class_name}):\n"
        return header_str

    def get_assert_fun_str(self, fun_name):
        assert_fun_str = '    @allure.step(title="接口返回结果校验")\n    def assert_%s(self, _assert=True, **kwargs):\n' \
                         '        assert unit_request.is_assert_true(self.res, _assert), "校验接口返回，缺少成功标识"\n' \
                         '        # out = self.sql_%s(**kwargs)\n' % (fun_name, fun_name)
        assert_fun_str += '        # flag = self.compare_json_list(self.res, out, [%s])\n' % \
                          ', '.join(['"%s"' % i for i in self.this_fun_list.api[fun_name].input
                                     if str(i).lower() not in self.page_and_size])
        assert_fun_str += '        assert True, "数据比较不一致"\n\n'
        return assert_fun_str

    def get_api_fun_header_str(self, fun_name):
        assert_path = self.get_path(fun_name, fun_type='asserts')
        fun_path = self.get_path(fun_name, fun_type='funs')
        api_path = self.get_path(fun_name, fun_type='apis')
        header_str = "import allure\n\n"
        header_str += f"from {assert_path.import_path} import {assert_path.class_name}\n"
        header_str += f"from {api_path.import_path.rsplit('.', 1)[0]} import {api_path.import_path.rsplit('.', 1)[1]}\n\n\n"
        header_str += f"class {fun_path.class_name}({assert_path.class_name}):\n"
        return header_str

    def get_api_fun_fun_str(self, fun_name):
        api_path = self.get_path(fun_name, fun_type='apis')
        api = self.this_fun_list.api[fun_name]
        data_list_tmp = []
        for n in api.input:
            if n in self.size_names:
                data_list_tmp.append(n.strip() + '=10')
            elif n in self.page_names:
                data_list_tmp.append(n.strip() + '=1')
            else:
                data_list_tmp.append(n.strip() + '="$None$"')
        api_fun_fun_str = f"    @allure.step(title=\"{api.title or api.url}\")\n"
        api_fun_fun_str += "    def %s(self, %s, _assert=True, " % (fun_name, ", ".join(data_list_tmp))
        data_list = [n for n in api.input if n not in self.page_and_size and n != 'headers']
        if str(api.method).lower() == "post" and len(data_list) > 2 and not (set(api.input) & set(self.page_and_size)):
            api_fun_fun_str += "_all_is_None=False, "
        api_fun_fun_str += " **kwargs):\n"
        api_fun_fun_str += f"        \"\"\"\n            url={api.url}\n"
        api_fun_fun_str += "".join([" " * 16 + i.strip() + "\n" for i in api.params.split('\n')
                                    if i.strip() and "params: userId" not in i])
        api_fun_fun_str += "        \"\"\"\n"
        if set(api.input) & set(self.page_and_size):
            for n in data_list:
                api_fun_fun_str += "        %s = self.get_list_choice(%s, list_or_dict=None, key=\"%s\")\n" % (n, n, n)
        else:
            for n in data_list:
                api_fun_fun_str += "        %s = self.get_value_choice(%s, list_or_dict=None, key=None" % (n, n)
                api_fun_fun_str += ", _all_is_None=_all_is_None)" if len(data_list) > 2 else ")"
        api_fun_fun_str += '\n' if data_list else ''
        api_fun_fun_str += "        _kwargs = self.get_kwargs(locals())\n"
        api_fun_fun_str += f"        self.res = {api_path.import_path.rsplit('.', 1)[1]}.{fun_name}(**_kwargs)\n\n"
        api_fun_fun_str += "        self.assert_%s(_assert, **_kwargs)\n" % fun_name
        if set(api.input) & set(self.page_and_size):
            api_fun_fun_str += "        self.set_output_value(_kwargs)\n"
        api_fun_fun_str += "        self.set_value(_kwargs)\n\n\n"

        return api_fun_fun_str




import allure

from service.app_t.asserts.points.asserts_points_points import AssertsPointsPoints
from service.app_t.apis.points import apis_points_points


class FunsPointsPoints(AssertsPointsPoints):
    @allure.step(title="查看积分明细- - 积分流水分页查询")
    def points_points_flowDetail(self, userId="$None$", _assert=True,  **kwargs):
        """
            url=/points/points/flowDetail
                params: headers : 请求头
        """
        userId = self.get_value_choice(userId, list_or_dict=None, key=None)
        _kwargs = self.get_kwargs(locals())
        self.res = apis_points_points.points_points_flowDetail(**_kwargs)

        self.assert_points_points_flowDetail(_assert, **_kwargs)
        self.set_value(_kwargs)


    @allure.step(title="积分统计-分页查询积分")
    def points_points_page(self, current=1, endTime="$None$", size=10, beforeTime="$None$", _assert=True,  **kwargs):
        """
            url=/points/points/page
                params: current :  :
                params: size :  :
                params: beforeTime :  :
                params: endTime :  :
                params: headers : 请求头
        """
        endTime = self.get_list_choice(endTime, list_or_dict=None, key="endTime")
        beforeTime = self.get_list_choice(beforeTime, list_or_dict=None, key="beforeTime")

        _kwargs = self.get_kwargs(locals())
        self.res = apis_points_points.points_points_page(**_kwargs)

        self.assert_points_points_page(_assert, **_kwargs)
        self.set_output_value(_kwargs)
        self.set_value(_kwargs)


    @allure.step(title="积分统计 - 导出")
    def points_points_download(self, current=1, endTime="$None$", size=10, beforeTime="$None$", _assert=True,  **kwargs):
        """
            url=/points/points/download
                params: current :  :
                params: size :  :
                params: endTime :  :
                params: beforeTime :  :
                params: headers : 请求头
        """
        endTime = self.get_list_choice(endTime, list_or_dict=None, key="endTime")
        beforeTime = self.get_list_choice(beforeTime, list_or_dict=None, key="beforeTime")

        _kwargs = self.get_kwargs(locals())
        self.res = apis_points_points.points_points_download(**_kwargs)

        self.assert_points_points_download(_assert, **_kwargs)
        self.set_output_value(_kwargs)
        self.set_value(_kwargs)


    @allure.step(title="用户中心-兑换明细 - 分页查询")
    def points_points_convertDetail(self, userId="$None$", _assert=True,  **kwargs):
        """
            url=/points/points/convertDetail
                params: headers : 请求头
        """
        userId = self.get_value_choice(userId, list_or_dict=None, key=None)
        _kwargs = self.get_kwargs(locals())
        self.res = apis_points_points.points_points_convertDetail(**_kwargs)

        self.assert_points_points_convertDetail(_assert, **_kwargs)
        self.set_value(_kwargs)





import allure

from service.app_t.asserts.open.haohan.asserts_open_haohan_rights import AssertsOpenHaohanRights
from service.app_t.apis.open.haohan import apis_open_haohan_rights


class FunsOpenHaohanRights(AssertsOpenHaohanRights):
    @allure.step(title="浩瀚模块 - 更改充电桩权益状态-Y")
    def open_haohan_rights_update(self, params="$None$", _assert=True,  **kwargs):
        """
            url=/open/haohan/rights/update
                params: params : object :
                data : string : 加密数据
                params: headers : 请求头
        """
        params = self.get_value_choice(params, list_or_dict=None, key=None)
        _kwargs = self.get_kwargs(locals())
        self.res = apis_open_haohan_rights.open_haohan_rights_update(**_kwargs)

        self.assert_open_haohan_rights_update(_assert, **_kwargs)
        self.set_value(_kwargs)





import allure

from service.app_t.asserts.open.haohan.asserts_open_haohan_relation import AssertsOpenHaohanRelation
from service.app_t.apis.open.haohan import apis_open_haohan_relation


class FunsOpenHaohanRelation(AssertsOpenHaohanRelation):
    @allure.step(title="浩瀚模块-关联关系-Y")
    def open_haohan_relation_update(self, userId="$None$", _assert=True,  **kwargs):
        """
            url=/open/haohan/relation/update
                params: headers : 请求头
        """
        userId = self.get_value_choice(userId, list_or_dict=None, key=None)
        _kwargs = self.get_kwargs(locals())
        self.res = apis_open_haohan_relation.open_haohan_relation_update(**_kwargs)

        self.assert_open_haohan_relation_update(_assert, **_kwargs)
        self.set_value(_kwargs)





from huhk.init_project import GetApi
from huhk.unit_request import UnitRequest


class Request(UnitRequest):
    pass


APP_KEY = "a63ca17b-3cf3-46cb-b8b6-9ad20518e1e1"


unit_request = Request("SIT", APP_KEY)
# 环境变量
variable = unit_request.variable
http_requester = unit_request.http_requester


if __name__ == "__main__":
    GetApi(name='app_t', app_key=APP_KEY).create_or_update_project()



from service.app_t.app_t_fun import AppTFun


class SqlsOpenHaohanRights(AppTFun):
    def sql_open_haohan_rights_update(self, **kwargs):
        # name = self.kwargs_pop(kwargs, 'name')  # 单独处理字段
        # self.kwargs_replace(kwargs, likes=[], ins=[], before_end=[])  # 模糊查询字段，数组包含查询字段，区间字段处理
        # kwargs["order_by"] = None  # 排序
        sql_str = self.get_sql_str("table_name", **kwargs)  # 生成sql语句
        # out = self.run_mysql(sql_str)  # 执行sql语句
        # return out




import allure

from service.app_t import http_requester
from huhk.unit_request import get_url


@allure.step(title="调接口：/points/pointsApp/signIn")
def points_pointsApp_signIn(userId=None, headers=None, **kwargs):
    """
    APP-用户签到
    up_time=1676254515

    params: userId :  : 用户ID
    params: headers : 请求头
    ====================返回======================
    params: code : number : 0成功;1失败
    params: msg : string : 
    params: data : boolean : true/false 签到成功/失败
    """
    _method = "GET"
    _url = "/points/pointsApp/signIn"

    _headers = {
    }
    _headers.update({"headers": headers})

    _data = {
        "userId": userId,  # 用户ID
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/points/pointsApp/myPoints")
def points_pointsApp_myPoints(userId=None, headers=None, **kwargs):
    """
    APP - 查看我的积分
    up_time=1676254812

    params: userId :  : 用户ID
    params: headers : 请求头
    ====================返回======================
    params: code : number : 
    params: msg : string : 
    params: data : object : 
              records : array : 
              size : number : 每页大小
              current : number : 当前页
              total : number : 总页数
    """
    _method = "GET"
    _url = "/points/pointsApp/myPoints"

    _headers = {
    }
    _headers.update({"headers": headers})

    _data = {
        "userId": userId,  # 用户ID
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/points/pointsApp/myPointsTotal")
def points_pointsApp_myPointsTotal(userId=None, headers=None, **kwargs):
    """
    APP - 总积分查询
    up_time=1676255216

    params: userId :  : 用户ID
    params: headers : 请求头
    ====================返回======================
    params: code : number : 
    params: msg : string : 
    params: data : number : 当前用户积分
    """
    _method = "GET"
    _url = "/points/pointsApp/myPointsTotal"

    _headers = {
    }
    _headers.update({"headers": headers})

    _data = {
        "userId": userId,  # 用户ID
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/points/pointsApp/signIn")
def points_pointsApp_signIn(userId=None, headers=None, **kwargs):
    """
    APP-用户签到
    up_time=1676254515

    params: userId :  : 用户ID
    params: headers : 请求头
    ====================返回======================
    params: code : number : 0成功;1失败
    params: msg : string : 
    params: data : boolean : true/false 签到成功/失败
    """
    _method = "GET"
    _url = "/points/pointsApp/signIn"

    _headers = {
    }
    _headers.update({"headers": headers})

    _data = {
        "userId": userId,  # 用户ID
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/points/pointsApp/signIn")
def points_pointsApp_signIn(userId=None, headers=None, **kwargs):
    """
    APP-用户签到
    up_time=1676254515

    params: userId :  : 用户ID
    params: headers : 请求头
    ====================返回======================
    params: code : number : 0成功;1失败
    params: msg : string : 
    params: data : boolean : true/false 签到成功/失败
    """
    _method = "GET"
    _url = "/points/pointsApp/signIn"

    _headers = {
    }
    _headers.update({"headers": headers})

    _data = {
        "userId": userId,  # 用户ID
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/points/pointsApp/signIn")
def points_pointsApp_signIn(userId=None, headers=None, **kwargs):
    """
    APP-用户签到
    up_time=1676254515

    params: userId :  : 用户ID
    params: headers : 请求头
    ====================返回======================
    params: code : number : 0成功;1失败
    params: msg : string : 
    params: data : boolean : true/false 签到成功/失败
    """
    _method = "GET"
    _url = "/points/pointsApp/signIn"

    _headers = {
    }
    _headers.update({"headers": headers})

    _data = {
        "userId": userId,  # 用户ID
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/points/pointsApp/signIn")
def points_pointsApp_signIn(userId=None, headers=None, **kwargs):
    """
    APP-用户签到
    up_time=1676254515

    params: userId :  : 用户ID
    params: headers : 请求头
    ====================返回======================
    params: code : number : 0成功;1失败
    params: msg : string : 
    params: data : boolean : true/false 签到成功/失败
    """
    _method = "GET"
    _url = "/points/pointsApp/signIn"

    _headers = {
    }
    _headers.update({"headers": headers})

    _data = {
        "userId": userId,  # 用户ID
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/points/pointsApp/signIn")
def points_pointsApp_signIn(userId=None, headers=None, **kwargs):
    """
    APP-用户签到
    up_time=1676254515

    params: userId :  : 用户ID
    params: headers : 请求头
    ====================返回======================
    params: code : number : 0成功;1失败
    params: msg : string : 
    params: data : boolean : true/false 签到成功/失败
    """
    _method = "GET"
    _url = "/points/pointsApp/signIn"

    _headers = {
    }
    _headers.update({"headers": headers})

    _data = {
        "userId": userId,  # 用户ID
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/points/pointsApp/signIn")
def points_pointsApp_signIn(userId=None, headers=None, **kwargs):
    """
    APP-用户签到
    up_time=1676254515

    params: userId :  : 用户ID
    params: headers : 请求头
    ====================返回======================
    params: code : number : 0成功;1失败
    params: msg : string : 
    params: data : boolean : true/false 签到成功/失败
    """
    _method = "GET"
    _url = "/points/pointsApp/signIn"

    _headers = {
    }
    _headers.update({"headers": headers})

    _data = {
        "userId": userId,  # 用户ID
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/points/pointsApp/signIn")
def points_pointsApp_signIn(userId=None, headers=None, **kwargs):
    """
    APP-用户签到
    up_time=1676254515

    params: userId :  : 用户ID
    params: headers : 请求头
    ====================返回======================
    params: code : number : 0成功;1失败
    params: msg : string : 
    params: data : boolean : true/false 签到成功/失败
    """
    _method = "GET"
    _url = "/points/pointsApp/signIn"

    _headers = {
    }
    _headers.update({"headers": headers})

    _data = {
        "userId": userId,  # 用户ID
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/points/pointsApp/signIn")
def points_pointsApp_signIn(userId=None, headers=None, **kwargs):
    """
    APP-用户签到
    up_time=1676254515

    params: userId :  : 用户ID
    params: headers : 请求头
    ====================返回======================
    params: code : number : 0成功;1失败
    params: msg : string : 
    params: data : boolean : true/false 签到成功/失败
    """
    _method = "GET"
    _url = "/points/pointsApp/signIn"

    _headers = {
    }
    _headers.update({"headers": headers})

    _data = {
        "userId": userId,  # 用户ID
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/points/pointsApp/signIn")
def points_pointsApp_signIn(userId=None, headers=None, **kwargs):
    """
    APP-用户签到
    up_time=1676254515

    params: userId :  : 用户ID
    params: headers : 请求头
    ====================返回======================
    params: code : number : 0成功;1失败
    params: msg : string : 
    params: data : boolean : true/false 签到成功/失败
    """
    _method = "GET"
    _url = "/points/pointsApp/signIn"

    _headers = {
    }
    _headers.update({"headers": headers})

    _data = {
        "userId": userId,  # 用户ID
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/points/pointsApp/signIn")
def points_pointsApp_signIn(userId=None, headers=None, **kwargs):
    """
    APP-用户签到
    up_time=1676254515

    params: userId :  : 用户ID
    params: headers : 请求头
    ====================返回======================
    params: code : number : 0成功;1失败
    params: msg : string : 
    params: data : boolean : true/false 签到成功/失败
    """
    _method = "GET"
    _url = "/points/pointsApp/signIn"

    _headers = {
    }
    _headers.update({"headers": headers})

    _data = {
        "userId": userId,  # 用户ID
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/points/pointsApp/signIn")
def points_pointsApp_signIn(userId=None, headers=None, **kwargs):
    """
    APP-用户签到
    up_time=1676254515

    params: userId :  : 用户ID
    params: headers : 请求头
    ====================返回======================
    params: code : number : 0成功;1失败
    params: msg : string : 
    params: data : boolean : true/false 签到成功/失败
    """
    _method = "GET"
    _url = "/points/pointsApp/signIn"

    _headers = {
    }
    _headers.update({"headers": headers})

    _data = {
        "userId": userId,  # 用户ID
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/points/pointsApp/signIn")
def points_pointsApp_signIn(userId=None, headers=None, **kwargs):
    """
    APP-用户签到
    up_time=1676254515

    params: userId :  : 用户ID
    params: headers : 请求头
    ====================返回======================
    params: code : number : 0成功;1失败
    params: msg : string : 
    params: data : boolean : true/false 签到成功/失败
    """
    _method = "GET"
    _url = "/points/pointsApp/signIn"

    _headers = {
    }
    _headers.update({"headers": headers})

    _data = {
        "userId": userId,  # 用户ID
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/points/pointsApp/signIn")
def points_pointsApp_signIn(userId=None, headers=None, **kwargs):
    """
    APP-用户签到
    up_time=1676254515

    params: userId :  : 用户ID
    params: headers : 请求头
    ====================返回======================
    params: code : number : 0成功;1失败
    params: msg : string : 
    params: data : boolean : true/false 签到成功/失败
    """
    _method = "GET"
    _url = "/points/pointsApp/signIn"

    _headers = {
    }
    _headers.update({"headers": headers})

    _data = {
        "userId": userId,  # 用户ID
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/points/pointsApp/signIn")
def points_pointsApp_signIn(userId=None, headers=None, **kwargs):
    """
    APP-用户签到
    up_time=1676254515

    params: userId :  : 用户ID
    params: headers : 请求头
    ====================返回======================
    params: code : number : 0成功;1失败
    params: msg : string : 
    params: data : boolean : true/false 签到成功/失败
    """
    _method = "GET"
    _url = "/points/pointsApp/signIn"

    _headers = {
    }
    _headers.update({"headers": headers})

    _data = {
        "userId": userId,  # 用户ID
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/points/pointsApp/signIn")
def points_pointsApp_signIn(userId=None, headers=None, **kwargs):
    """
    APP-用户签到
    up_time=1676254515

    params: userId :  : 用户ID
    params: headers : 请求头
    ====================返回======================
    params: code : number : 0成功;1失败
    params: msg : string : 
    params: data : boolean : true/false 签到成功/失败
    """
    _method = "GET"
    _url = "/points/pointsApp/signIn"

    _headers = {
    }
    _headers.update({"headers": headers})

    _data = {
        "userId": userId,  # 用户ID
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/points/pointsApp/signIn")
def points_pointsApp_signIn(userId=None, headers=None, **kwargs):
    """
    APP-用户签到
    up_time=1676254515

    params: userId :  : 用户ID
    params: headers : 请求头
    ====================返回======================
    params: code : number : 0成功;1失败
    params: msg : string : 
    params: data : boolean : true/false 签到成功/失败
    """
    _method = "GET"
    _url = "/points/pointsApp/signIn"

    _headers = {
    }
    _headers.update({"headers": headers})

    _data = {
        "userId": userId,  # 用户ID
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/points/pointsApp/signIn")
def points_pointsApp_signIn(userId=None, headers=None, **kwargs):
    """
    APP-用户签到
    up_time=1676254515

    params: userId :  : 用户ID
    params: headers : 请求头
    ====================返回======================
    params: code : number : 0成功;1失败
    params: msg : string : 
    params: data : boolean : true/false 签到成功/失败
    """
    _method = "GET"
    _url = "/points/pointsApp/signIn"

    _headers = {
    }
    _headers.update({"headers": headers})

    _data = {
        "userId": userId,  # 用户ID
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/points/pointsApp/signIn")
def points_pointsApp_signIn(userId=None, headers=None, **kwargs):
    """
    APP-用户签到
    up_time=1676254515

    params: userId :  : 用户ID
    params: headers : 请求头
    ====================返回======================
    params: code : number : 0成功;1失败
    params: msg : string : 
    params: data : boolean : true/false 签到成功/失败
    """
    _method = "GET"
    _url = "/points/pointsApp/signIn"

    _headers = {
    }
    _headers.update({"headers": headers})

    _data = {
        "userId": userId,  # 用户ID
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/points/pointsApp/signIn")
def points_pointsApp_signIn(userId=None, headers=None, **kwargs):
    """
    APP-用户签到
    up_time=1676254515

    params: userId :  : 用户ID
    params: headers : 请求头
    ====================返回======================
    params: code : number : 0成功;1失败
    params: msg : string : 
    params: data : boolean : true/false 签到成功/失败
    """
    _method = "GET"
    _url = "/points/pointsApp/signIn"

    _headers = {
    }
    _headers.update({"headers": headers})

    _data = {
        "userId": userId,  # 用户ID
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/points/pointsApp/signIn")
def points_pointsApp_signIn(userId=None, headers=None, **kwargs):
    """
    APP-用户签到
    up_time=1676254515

    params: userId :  : 用户ID
    params: headers : 请求头
    ====================返回======================
    params: code : number : 0成功;1失败
    params: msg : string : 
    params: data : boolean : true/false 签到成功/失败
    """
    _method = "GET"
    _url = "/points/pointsApp/signIn"

    _headers = {
    }
    _headers.update({"headers": headers})

    _data = {
        "userId": userId,  # 用户ID
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/points/pointsApp/signIn")
def points_pointsApp_signIn(userId=None, headers=None, **kwargs):
    """
    APP-用户签到
    up_time=1676254515

    params: userId :  : 用户ID
    params: headers : 请求头
    ====================返回======================
    params: code : number : 0成功;1失败
    params: msg : string : 
    params: data : boolean : true/false 签到成功/失败
    """
    _method = "GET"
    _url = "/points/pointsApp/signIn"

    _headers = {
    }
    _headers.update({"headers": headers})

    _data = {
        "userId": userId,  # 用户ID
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/points/pointsApp/signIn")
def points_pointsApp_signIn(userId=None, headers=None, **kwargs):
    """
    APP-用户签到
    up_time=1676254515

    params: userId :  : 用户ID
    params: headers : 请求头
    ====================返回======================
    params: code : number : 0成功;1失败
    params: msg : string : 
    params: data : boolean : true/false 签到成功/失败
    """
    _method = "GET"
    _url = "/points/pointsApp/signIn"

    _headers = {
    }
    _headers.update({"headers": headers})

    _data = {
        "userId": userId,  # 用户ID
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/points/pointsApp/signIn")
def points_pointsApp_signIn(userId=None, headers=None, **kwargs):
    """
    APP-用户签到
    up_time=1676254515

    params: userId :  : 用户ID
    params: headers : 请求头
    ====================返回======================
    params: code : number : 0成功;1失败
    params: msg : string : 
    params: data : boolean : true/false 签到成功/失败
    """
    _method = "GET"
    _url = "/points/pointsApp/signIn"

    _headers = {
    }
    _headers.update({"headers": headers})

    _data = {
        "userId": userId,  # 用户ID
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/points/pointsApp/signIn")
def points_pointsApp_signIn(userId=None, headers=None, **kwargs):
    """
    APP-用户签到
    up_time=1676254515

    params: userId :  : 用户ID
    params: headers : 请求头
    ====================返回======================
    params: code : number : 0成功;1失败
    params: msg : string : 
    params: data : boolean : true/false 签到成功/失败
    """
    _method = "GET"
    _url = "/points/pointsApp/signIn"

    _headers = {
    }
    _headers.update({"headers": headers})

    _data = {
        "userId": userId,  # 用户ID
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/points/pointsApp/signIn")
def points_pointsApp_signIn(userId=None, headers=None, **kwargs):
    """
    APP-用户签到
    up_time=1676254515

    params: userId :  : 用户ID
    params: headers : 请求头
    ====================返回======================
    params: code : number : 0成功;1失败
    params: msg : string : 
    params: data : boolean : true/false 签到成功/失败
    """
    _method = "GET"
    _url = "/points/pointsApp/signIn"

    _headers = {
    }
    _headers.update({"headers": headers})

    _data = {
        "userId": userId,  # 用户ID
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/points/pointsApp/signIn")
def points_pointsApp_signIn(userId=None, headers=None, **kwargs):
    """
    APP-用户签到
    up_time=1676254515

    params: userId :  : 用户ID
    params: headers : 请求头
    ====================返回======================
    params: code : number : 0成功;1失败
    params: msg : string : 
    params: data : boolean : true/false 签到成功/失败
    """
    _method = "GET"
    _url = "/points/pointsApp/signIn"

    _headers = {
    }
    _headers.update({"headers": headers})

    _data = {
        "userId": userId,  # 用户ID
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/points/pointsApp/signIn")
def points_pointsApp_signIn(userId=None, headers=None, **kwargs):
    """
    APP-用户签到
    up_time=1676254515

    params: userId :  : 用户ID
    params: headers : 请求头
    ====================返回======================
    params: code : number : 0成功;1失败
    params: msg : string : 
    params: data : boolean : true/false 签到成功/失败
    """
    _method = "GET"
    _url = "/points/pointsApp/signIn"

    _headers = {
    }
    _headers.update({"headers": headers})

    _data = {
        "userId": userId,  # 用户ID
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/points/pointsApp/signIn")
def points_pointsApp_signIn(userId=None, headers=None, **kwargs):
    """
    APP-用户签到
    up_time=1676254515

    params: userId :  : 用户ID
    params: headers : 请求头
    ====================返回======================
    params: code : number : 0成功;1失败
    params: msg : string : 
    params: data : boolean : true/false 签到成功/失败
    """
    _method = "GET"
    _url = "/points/pointsApp/signIn"

    _headers = {
    }
    _headers.update({"headers": headers})

    _data = {
        "userId": userId,  # 用户ID
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/points/pointsApp/signIn")
def points_pointsApp_signIn(userId=None, headers=None, **kwargs):
    """
    APP-用户签到
    up_time=1676254515

    params: userId :  : 用户ID
    params: headers : 请求头
    ====================返回======================
    params: code : number : 0成功;1失败
    params: msg : string : 
    params: data : boolean : true/false 签到成功/失败
    """
    _method = "GET"
    _url = "/points/pointsApp/signIn"

    _headers = {
    }
    _headers.update({"headers": headers})

    _data = {
        "userId": userId,  # 用户ID
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/points/pointsApp/signIn")
def points_pointsApp_signIn(userId=None, headers=None, **kwargs):
    """
    APP-用户签到
    up_time=1676254515

    params: userId :  : 用户ID
    params: headers : 请求头
    ====================返回======================
    params: code : number : 0成功;1失败
    params: msg : string : 
    params: data : boolean : true/false 签到成功/失败
    """
    _method = "GET"
    _url = "/points/pointsApp/signIn"

    _headers = {
    }
    _headers.update({"headers": headers})

    _data = {
        "userId": userId,  # 用户ID
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)





import allure

from service.app_t import http_requester
from huhk.unit_request import get_url


@allure.step(title="调接口：/points/points/flowDetail")
def points_points_flowDetail(userId=None, headers=None, **kwargs):
    """
    查看积分明细- - 积分流水分页查询
    up_time=1676254506

    params: userId :  : 用户ID
    params: headers : 请求头
    ====================返回======================
    params: code : number : 
    params: msg : string : 
    params: data : object : 
              records : array : 
              size : number : 每页大小
              current : number : 当前页
              total : number : 总页数
    """
    _method = "GET"
    _url = "/points/points/flowDetail"

    _headers = {
    }
    _headers.update({"headers": headers})

    _data = {
        "userId": userId,  # 用户ID
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/points/points/page")
def points_points_page(current=None, endTime=None, size=None, beforeTime=None, headers=None, **kwargs):
    """
    积分统计-分页查询积分
    up_time=1676269112

    params: current :  : 
    params: size :  : 
    params: beforeTime :  : 
    params: endTime :  : 
    params: headers : 请求头
    ====================返回======================
    params: code : string : 
    params: msg : string : 
    params: data : object : 
              records : object : 日期
              size : string : 
              current : string : 
              total : string : 
    """
    _method = "GET"
    _url = "/points/points/page"

    _headers = {
    }
    _headers.update({"headers": headers})

    _data = {
        "current": current,
        "size": size,
        "beforeTime": beforeTime,
        "endTime": endTime,
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/points/points/download")
def points_points_download(current=None, endTime=None, size=None, beforeTime=None, headers=None, **kwargs):
    """
    积分统计 - 导出
    up_time=1676266332

    params: current :  : 
    params: size :  : 
    params: endTime :  : 
    params: beforeTime :  : 
    params: headers : 请求头
    ====================返回======================
    """
    _method = "GET"
    _url = "/points/points/download"

    _headers = {
    }
    _headers.update({"headers": headers})

    _data = {
        "current": current,
        "size": size,
        "endTime": endTime,
        "beforeTime": beforeTime,
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/points/points/convertDetail")
def points_points_convertDetail(userId=None, headers=None, **kwargs):
    """
    用户中心-兑换明细 - 分页查询
    up_time=1676267280

    params: userId :  : 用户ID
    params: headers : 请求头
    ====================返回======================
    params: code : number : 
    params: msg : string : 
    params: data : object : 
              records : array : 
              size : number : 每页大小
              current : number : 当前页
              total : number : 总页数
    """
    _method = "GET"
    _url = "/points/points/convertDetail"

    _headers = {
    }
    _headers.update({"headers": headers})

    _data = {
        "userId": userId,  # 用户ID
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/points/points/flowDetail")
def points_points_flowDetail(userId=None, headers=None, **kwargs):
    """
    查看积分明细- - 积分流水分页查询
    up_time=1676254506

    params: userId :  : 用户ID
    params: headers : 请求头
    ====================返回======================
    params: code : number : 
    params: msg : string : 
    params: data : object : 
              records : array : 
              size : number : 每页大小
              current : number : 当前页
              total : number : 总页数
    """
    _method = "GET"
    _url = "/points/points/flowDetail"

    _headers = {
    }
    _headers.update({"headers": headers})

    _data = {
        "userId": userId,  # 用户ID
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/points/points/flowDetail")
def points_points_flowDetail(userId=None, headers=None, **kwargs):
    """
    查看积分明细- - 积分流水分页查询
    up_time=1676254506

    params: userId :  : 用户ID
    params: headers : 请求头
    ====================返回======================
    params: code : number : 
    params: msg : string : 
    params: data : object : 
              records : array : 
              size : number : 每页大小
              current : number : 当前页
              total : number : 总页数
    """
    _method = "GET"
    _url = "/points/points/flowDetail"

    _headers = {
    }
    _headers.update({"headers": headers})

    _data = {
        "userId": userId,  # 用户ID
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/points/points/flowDetail")
def points_points_flowDetail(userId=None, headers=None, **kwargs):
    """
    查看积分明细- - 积分流水分页查询
    up_time=1676254506

    params: userId :  : 用户ID
    params: headers : 请求头
    ====================返回======================
    params: code : number : 
    params: msg : string : 
    params: data : object : 
              records : array : 
              size : number : 每页大小
              current : number : 当前页
              total : number : 总页数
    """
    _method = "GET"
    _url = "/points/points/flowDetail"

    _headers = {
    }
    _headers.update({"headers": headers})

    _data = {
        "userId": userId,  # 用户ID
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/points/points/flowDetail")
def points_points_flowDetail(userId=None, headers=None, **kwargs):
    """
    查看积分明细- - 积分流水分页查询
    up_time=1676254506

    params: userId :  : 用户ID
    params: headers : 请求头
    ====================返回======================
    params: code : number : 
    params: msg : string : 
    params: data : object : 
              records : array : 
              size : number : 每页大小
              current : number : 当前页
              total : number : 总页数
    """
    _method = "GET"
    _url = "/points/points/flowDetail"

    _headers = {
    }
    _headers.update({"headers": headers})

    _data = {
        "userId": userId,  # 用户ID
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/points/points/flowDetail")
def points_points_flowDetail(userId=None, headers=None, **kwargs):
    """
    查看积分明细- - 积分流水分页查询
    up_time=1676254506

    params: userId :  : 用户ID
    params: headers : 请求头
    ====================返回======================
    params: code : number : 
    params: msg : string : 
    params: data : object : 
              records : array : 
              size : number : 每页大小
              current : number : 当前页
              total : number : 总页数
    """
    _method = "GET"
    _url = "/points/points/flowDetail"

    _headers = {
    }
    _headers.update({"headers": headers})

    _data = {
        "userId": userId,  # 用户ID
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/points/points/flowDetail")
def points_points_flowDetail(userId=None, headers=None, **kwargs):
    """
    查看积分明细- - 积分流水分页查询
    up_time=1676254506

    params: userId :  : 用户ID
    params: headers : 请求头
    ====================返回======================
    params: code : number : 
    params: msg : string : 
    params: data : object : 
              records : array : 
              size : number : 每页大小
              current : number : 当前页
              total : number : 总页数
    """
    _method = "GET"
    _url = "/points/points/flowDetail"

    _headers = {
    }
    _headers.update({"headers": headers})

    _data = {
        "userId": userId,  # 用户ID
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/points/points/flowDetail")
def points_points_flowDetail(userId=None, headers=None, **kwargs):
    """
    查看积分明细- - 积分流水分页查询
    up_time=1676254506

    params: userId :  : 用户ID
    params: headers : 请求头
    ====================返回======================
    params: code : number : 
    params: msg : string : 
    params: data : object : 
              records : array : 
              size : number : 每页大小
              current : number : 当前页
              total : number : 总页数
    """
    _method = "GET"
    _url = "/points/points/flowDetail"

    _headers = {
    }
    _headers.update({"headers": headers})

    _data = {
        "userId": userId,  # 用户ID
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/points/points/flowDetail")
def points_points_flowDetail(userId=None, headers=None, **kwargs):
    """
    查看积分明细- - 积分流水分页查询
    up_time=1676254506

    params: userId :  : 用户ID
    params: headers : 请求头
    ====================返回======================
    params: code : number : 
    params: msg : string : 
    params: data : object : 
              records : array : 
              size : number : 每页大小
              current : number : 当前页
              total : number : 总页数
    """
    _method = "GET"
    _url = "/points/points/flowDetail"

    _headers = {
    }
    _headers.update({"headers": headers})

    _data = {
        "userId": userId,  # 用户ID
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/points/points/flowDetail")
def points_points_flowDetail(userId=None, headers=None, **kwargs):
    """
    查看积分明细- - 积分流水分页查询
    up_time=1676254506

    params: userId :  : 用户ID
    params: headers : 请求头
    ====================返回======================
    params: code : number : 
    params: msg : string : 
    params: data : object : 
              records : array : 
              size : number : 每页大小
              current : number : 当前页
              total : number : 总页数
    """
    _method = "GET"
    _url = "/points/points/flowDetail"

    _headers = {
    }
    _headers.update({"headers": headers})

    _data = {
        "userId": userId,  # 用户ID
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/points/points/flowDetail")
def points_points_flowDetail(userId=None, headers=None, **kwargs):
    """
    查看积分明细- - 积分流水分页查询
    up_time=1676254506

    params: userId :  : 用户ID
    params: headers : 请求头
    ====================返回======================
    params: code : number : 
    params: msg : string : 
    params: data : object : 
              records : array : 
              size : number : 每页大小
              current : number : 当前页
              total : number : 总页数
    """
    _method = "GET"
    _url = "/points/points/flowDetail"

    _headers = {
    }
    _headers.update({"headers": headers})

    _data = {
        "userId": userId,  # 用户ID
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/points/points/flowDetail")
def points_points_flowDetail(userId=None, headers=None, **kwargs):
    """
    查看积分明细- - 积分流水分页查询
    up_time=1676254506

    params: userId :  : 用户ID
    params: headers : 请求头
    ====================返回======================
    params: code : number : 
    params: msg : string : 
    params: data : object : 
              records : array : 
              size : number : 每页大小
              current : number : 当前页
              total : number : 总页数
    """
    _method = "GET"
    _url = "/points/points/flowDetail"

    _headers = {
    }
    _headers.update({"headers": headers})

    _data = {
        "userId": userId,  # 用户ID
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/points/points/flowDetail")
def points_points_flowDetail(userId=None, headers=None, **kwargs):
    """
    查看积分明细- - 积分流水分页查询
    up_time=1676254506

    params: userId :  : 用户ID
    params: headers : 请求头
    ====================返回======================
    params: code : number : 
    params: msg : string : 
    params: data : object : 
              records : array : 
              size : number : 每页大小
              current : number : 当前页
              total : number : 总页数
    """
    _method = "GET"
    _url = "/points/points/flowDetail"

    _headers = {
    }
    _headers.update({"headers": headers})

    _data = {
        "userId": userId,  # 用户ID
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/points/points/flowDetail")
def points_points_flowDetail(userId=None, headers=None, **kwargs):
    """
    查看积分明细- - 积分流水分页查询
    up_time=1676254506

    params: userId :  : 用户ID
    params: headers : 请求头
    ====================返回======================
    params: code : number : 
    params: msg : string : 
    params: data : object : 
              records : array : 
              size : number : 每页大小
              current : number : 当前页
              total : number : 总页数
    """
    _method = "GET"
    _url = "/points/points/flowDetail"

    _headers = {
    }
    _headers.update({"headers": headers})

    _data = {
        "userId": userId,  # 用户ID
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/points/points/flowDetail")
def points_points_flowDetail(userId=None, headers=None, **kwargs):
    """
    查看积分明细- - 积分流水分页查询
    up_time=1676254506

    params: userId :  : 用户ID
    params: headers : 请求头
    ====================返回======================
    params: code : number : 
    params: msg : string : 
    params: data : object : 
              records : array : 
              size : number : 每页大小
              current : number : 当前页
              total : number : 总页数
    """
    _method = "GET"
    _url = "/points/points/flowDetail"

    _headers = {
    }
    _headers.update({"headers": headers})

    _data = {
        "userId": userId,  # 用户ID
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/points/points/flowDetail")
def points_points_flowDetail(userId=None, headers=None, **kwargs):
    """
    查看积分明细- - 积分流水分页查询
    up_time=1676254506

    params: userId :  : 用户ID
    params: headers : 请求头
    ====================返回======================
    params: code : number : 
    params: msg : string : 
    params: data : object : 
              records : array : 
              size : number : 每页大小
              current : number : 当前页
              total : number : 总页数
    """
    _method = "GET"
    _url = "/points/points/flowDetail"

    _headers = {
    }
    _headers.update({"headers": headers})

    _data = {
        "userId": userId,  # 用户ID
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/points/points/flowDetail")
def points_points_flowDetail(userId=None, headers=None, **kwargs):
    """
    查看积分明细- - 积分流水分页查询
    up_time=1676254506

    params: userId :  : 用户ID
    params: headers : 请求头
    ====================返回======================
    params: code : number : 
    params: msg : string : 
    params: data : object : 
              records : array : 
              size : number : 每页大小
              current : number : 当前页
              total : number : 总页数
    """
    _method = "GET"
    _url = "/points/points/flowDetail"

    _headers = {
    }
    _headers.update({"headers": headers})

    _data = {
        "userId": userId,  # 用户ID
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/points/points/flowDetail")
def points_points_flowDetail(userId=None, headers=None, **kwargs):
    """
    查看积分明细- - 积分流水分页查询
    up_time=1676254506

    params: userId :  : 用户ID
    params: headers : 请求头
    ====================返回======================
    params: code : number : 
    params: msg : string : 
    params: data : object : 
              records : array : 
              size : number : 每页大小
              current : number : 当前页
              total : number : 总页数
    """
    _method = "GET"
    _url = "/points/points/flowDetail"

    _headers = {
    }
    _headers.update({"headers": headers})

    _data = {
        "userId": userId,  # 用户ID
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/points/points/flowDetail")
def points_points_flowDetail(userId=None, headers=None, **kwargs):
    """
    查看积分明细- - 积分流水分页查询
    up_time=1676254506

    params: userId :  : 用户ID
    params: headers : 请求头
    ====================返回======================
    params: code : number : 
    params: msg : string : 
    params: data : object : 
              records : array : 
              size : number : 每页大小
              current : number : 当前页
              total : number : 总页数
    """
    _method = "GET"
    _url = "/points/points/flowDetail"

    _headers = {
    }
    _headers.update({"headers": headers})

    _data = {
        "userId": userId,  # 用户ID
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/points/points/flowDetail")
def points_points_flowDetail(userId=None, headers=None, **kwargs):
    """
    查看积分明细- - 积分流水分页查询
    up_time=1676254506

    params: userId :  : 用户ID
    params: headers : 请求头
    ====================返回======================
    params: code : number : 
    params: msg : string : 
    params: data : object : 
              records : array : 
              size : number : 每页大小
              current : number : 当前页
              total : number : 总页数
    """
    _method = "GET"
    _url = "/points/points/flowDetail"

    _headers = {
    }
    _headers.update({"headers": headers})

    _data = {
        "userId": userId,  # 用户ID
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/points/points/flowDetail")
def points_points_flowDetail(userId=None, headers=None, **kwargs):
    """
    查看积分明细- - 积分流水分页查询
    up_time=1676254506

    params: userId :  : 用户ID
    params: headers : 请求头
    ====================返回======================
    params: code : number : 
    params: msg : string : 
    params: data : object : 
              records : array : 
              size : number : 每页大小
              current : number : 当前页
              total : number : 总页数
    """
    _method = "GET"
    _url = "/points/points/flowDetail"

    _headers = {
    }
    _headers.update({"headers": headers})

    _data = {
        "userId": userId,  # 用户ID
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/points/points/flowDetail")
def points_points_flowDetail(userId=None, headers=None, **kwargs):
    """
    查看积分明细- - 积分流水分页查询
    up_time=1676254506

    params: userId :  : 用户ID
    params: headers : 请求头
    ====================返回======================
    params: code : number : 
    params: msg : string : 
    params: data : object : 
              records : array : 
              size : number : 每页大小
              current : number : 当前页
              total : number : 总页数
    """
    _method = "GET"
    _url = "/points/points/flowDetail"

    _headers = {
    }
    _headers.update({"headers": headers})

    _data = {
        "userId": userId,  # 用户ID
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/points/points/flowDetail")
def points_points_flowDetail(userId=None, headers=None, **kwargs):
    """
    查看积分明细- - 积分流水分页查询
    up_time=1676254506

    params: userId :  : 用户ID
    params: headers : 请求头
    ====================返回======================
    params: code : number : 
    params: msg : string : 
    params: data : object : 
              records : array : 
              size : number : 每页大小
              current : number : 当前页
              total : number : 总页数
    """
    _method = "GET"
    _url = "/points/points/flowDetail"

    _headers = {
    }
    _headers.update({"headers": headers})

    _data = {
        "userId": userId,  # 用户ID
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/points/points/flowDetail")
def points_points_flowDetail(userId=None, headers=None, **kwargs):
    """
    查看积分明细- - 积分流水分页查询
    up_time=1676254506

    params: userId :  : 用户ID
    params: headers : 请求头
    ====================返回======================
    params: code : number : 
    params: msg : string : 
    params: data : object : 
              records : array : 
              size : number : 每页大小
              current : number : 当前页
              total : number : 总页数
    """
    _method = "GET"
    _url = "/points/points/flowDetail"

    _headers = {
    }
    _headers.update({"headers": headers})

    _data = {
        "userId": userId,  # 用户ID
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/points/points/flowDetail")
def points_points_flowDetail(userId=None, headers=None, **kwargs):
    """
    查看积分明细- - 积分流水分页查询
    up_time=1676254506

    params: userId :  : 用户ID
    params: headers : 请求头
    ====================返回======================
    params: code : number : 
    params: msg : string : 
    params: data : object : 
              records : array : 
              size : number : 每页大小
              current : number : 当前页
              total : number : 总页数
    """
    _method = "GET"
    _url = "/points/points/flowDetail"

    _headers = {
    }
    _headers.update({"headers": headers})

    _data = {
        "userId": userId,  # 用户ID
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/points/points/flowDetail")
def points_points_flowDetail(userId=None, headers=None, **kwargs):
    """
    查看积分明细- - 积分流水分页查询
    up_time=1676254506

    params: userId :  : 用户ID
    params: headers : 请求头
    ====================返回======================
    params: code : number : 
    params: msg : string : 
    params: data : object : 
              records : array : 
              size : number : 每页大小
              current : number : 当前页
              total : number : 总页数
    """
    _method = "GET"
    _url = "/points/points/flowDetail"

    _headers = {
    }
    _headers.update({"headers": headers})

    _data = {
        "userId": userId,  # 用户ID
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/points/points/flowDetail")
def points_points_flowDetail(userId=None, headers=None, **kwargs):
    """
    查看积分明细- - 积分流水分页查询
    up_time=1676254506

    params: userId :  : 用户ID
    params: headers : 请求头
    ====================返回======================
    params: code : number : 
    params: msg : string : 
    params: data : object : 
              records : array : 
              size : number : 每页大小
              current : number : 当前页
              total : number : 总页数
    """
    _method = "GET"
    _url = "/points/points/flowDetail"

    _headers = {
    }
    _headers.update({"headers": headers})

    _data = {
        "userId": userId,  # 用户ID
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/points/points/flowDetail")
def points_points_flowDetail(userId=None, headers=None, **kwargs):
    """
    查看积分明细- - 积分流水分页查询
    up_time=1676254506

    params: userId :  : 用户ID
    params: headers : 请求头
    ====================返回======================
    params: code : number : 
    params: msg : string : 
    params: data : object : 
              records : array : 
              size : number : 每页大小
              current : number : 当前页
              total : number : 总页数
    """
    _method = "GET"
    _url = "/points/points/flowDetail"

    _headers = {
    }
    _headers.update({"headers": headers})

    _data = {
        "userId": userId,  # 用户ID
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/points/points/flowDetail")
def points_points_flowDetail(userId=None, headers=None, **kwargs):
    """
    查看积分明细- - 积分流水分页查询
    up_time=1676254506

    params: userId :  : 用户ID
    params: headers : 请求头
    ====================返回======================
    params: code : number : 
    params: msg : string : 
    params: data : object : 
              records : array : 
              size : number : 每页大小
              current : number : 当前页
              total : number : 总页数
    """
    _method = "GET"
    _url = "/points/points/flowDetail"

    _headers = {
    }
    _headers.update({"headers": headers})

    _data = {
        "userId": userId,  # 用户ID
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/points/points/flowDetail")
def points_points_flowDetail(userId=None, headers=None, **kwargs):
    """
    查看积分明细- - 积分流水分页查询
    up_time=1676254506

    params: userId :  : 用户ID
    params: headers : 请求头
    ====================返回======================
    params: code : number : 
    params: msg : string : 
    params: data : object : 
              records : array : 
              size : number : 每页大小
              current : number : 当前页
              total : number : 总页数
    """
    _method = "GET"
    _url = "/points/points/flowDetail"

    _headers = {
    }
    _headers.update({"headers": headers})

    _data = {
        "userId": userId,  # 用户ID
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/points/points/flowDetail")
def points_points_flowDetail(userId=None, headers=None, **kwargs):
    """
    查看积分明细- - 积分流水分页查询
    up_time=1676254506

    params: userId :  : 用户ID
    params: headers : 请求头
    ====================返回======================
    params: code : number : 
    params: msg : string : 
    params: data : object : 
              records : array : 
              size : number : 每页大小
              current : number : 当前页
              total : number : 总页数
    """
    _method = "GET"
    _url = "/points/points/flowDetail"

    _headers = {
    }
    _headers.update({"headers": headers})

    _data = {
        "userId": userId,  # 用户ID
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)





from setuptools import setup, find_packages

from huhk.unit_fun import FunBase

setup(
    name='huhk',  # 对外模块的名字
    version=FunBase.get_version(),  # 版本号
    description='接口自动化',  # 描述
    author='胡杭凯',  # 作者
    author_email='3173825608@qq.com',
    # package_dir={"": "huhk"},
    packages=find_packages(),
    package_data={'by': ['常用命令.py'],},
    include_package_data=True,
    entry_points={'console_scripts': ['huhk=huhk.case_project.main:main']},
    python_requires=">=3.0",
    install_requires=[
        "faker",
        "openpyxl",
        "apscheduler",
        "rsa",
        "pyDes",
        "pycryptodome",
        "xlsxwriter",
        "pandas",
        "apache-beam",
        "pytest",
        "setuptools",
        "twine",
        "requests==2.29.0",
        "pandas",
        "click",
    ],
)


